# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Kinesis"
prefix = "kinesis"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddTagsToStream = Action("AddTagsToStream")
CreateStream = Action("CreateStream")
DecreaseStreamRetentionPeriod = Action("DecreaseStreamRetentionPeriod")
DeleteStream = Action("DeleteStream")
DeregisterStreamConsumer = Action("DeregisterStreamConsumer")
DescribeLimits = Action("DescribeLimits")
DescribeStream = Action("DescribeStream")
DescribeStreamConsumer = Action("DescribeStreamConsumer")
DescribeStreamSummary = Action("DescribeStreamSummary")
DisableEnhancedMonitoring = Action("DisableEnhancedMonitoring")
EnableEnhancedMonitoring = Action("EnableEnhancedMonitoring")
GetRecords = Action("GetRecords")
GetShardIterator = Action("GetShardIterator")
IncreaseStreamRetentionPeriod = Action("IncreaseStreamRetentionPeriod")
ListShards = Action("ListShards")
ListStreamConsumers = Action("ListStreamConsumers")
ListStreams = Action("ListStreams")
ListTagsForStream = Action("ListTagsForStream")
MergeShards = Action("MergeShards")
PutRecord = Action("PutRecord")
PutRecords = Action("PutRecords")
RegisterStreamConsumer = Action("RegisterStreamConsumer")
RemoveTagsFromStream = Action("RemoveTagsFromStream")
SplitShard = Action("SplitShard")
StartStreamEncryption = Action("StartStreamEncryption")
StopStreamEncryption = Action("StopStreamEncryption")
SubscribeToShard = Action("SubscribeToShard")
UpdateShardCount = Action("UpdateShardCount")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Organizations"
prefix = "organizations"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptHandshake = Action("AcceptHandshake")
AttachPolicy = Action("AttachPolicy")
CancelHandshake = Action("CancelHandshake")
CreateAccount = Action("CreateAccount")
CreateGovCloudAccount = Action("CreateGovCloudAccount")
CreateOrganization = Action("CreateOrganization")
CreateOrganizationalUnit = Action("CreateOrganizationalUnit")
CreatePolicy = Action("CreatePolicy")
DeclineHandshake = Action("DeclineHandshake")
DeleteOrganization = Action("DeleteOrganization")
DeleteOrganizationalUnit = Action("DeleteOrganizationalUnit")
DeletePolicy = Action("DeletePolicy")
DeregisterDelegatedAdministrator = Action("DeregisterDelegatedAdministrator")
DescribeAccount = Action("DescribeAccount")
DescribeCreateAccountStatus = Action("DescribeCreateAccountStatus")
DescribeEffectivePolicy = Action("DescribeEffectivePolicy")
DescribeHandshake = Action("DescribeHandshake")
DescribeOrganization = Action("DescribeOrganization")
DescribeOrganizationalUnit = Action("DescribeOrganizationalUnit")
DescribePolicy = Action("DescribePolicy")
DetachPolicy = Action("DetachPolicy")
DisableAWSServiceAccess = Action("DisableAWSServiceAccess")
DisablePolicyType = Action("DisablePolicyType")
EnableAWSServiceAccess = Action("EnableAWSServiceAccess")
EnableAllFeatures = Action("EnableAllFeatures")
EnablePolicyType = Action("EnablePolicyType")
InviteAccountToOrganization = Action("InviteAccountToOrganization")
LeaveOrganization = Action("LeaveOrganization")
ListAWSServiceAccessForOrganization = Action("ListAWSServiceAccessForOrganization")
ListAccounts = Action("ListAccounts")
ListAccountsForParent = Action("ListAccountsForParent")
ListChildren = Action("ListChildren")
ListCreateAccountStatus = Action("ListCreateAccountStatus")
ListDelegatedAdministrators = Action("ListDelegatedAdministrators")
ListDelegatedServicesForAccount = Action("ListDelegatedServicesForAccount")
ListHandshakesForAccount = Action("ListHandshakesForAccount")
ListHandshakesForOrganization = Action("ListHandshakesForOrganization")
ListOrganizationalUnitsForParent = Action("ListOrganizationalUnitsForParent")
ListParents = Action("ListParents")
ListPolicies = Action("ListPolicies")
ListPoliciesForTarget = Action("ListPoliciesForTarget")
ListRoots = Action("ListRoots")
ListTagsForResource = Action("ListTagsForResource")
ListTargetsForPolicy = Action("ListTargetsForPolicy")
MoveAccount = Action("MoveAccount")
RegisterDelegatedAdministrator = Action("RegisterDelegatedAdministrator")
RemoveAccountFromOrganization = Action("RemoveAccountFromOrganization")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateOrganizationalUnit = Action("UpdateOrganizationalUnit")
UpdatePolicy = Action("UpdatePolicy")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Device Farm"
prefix = "devicefarm"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateDevicePool = Action("CreateDevicePool")
CreateInstanceProfile = Action("CreateInstanceProfile")
CreateNetworkProfile = Action("CreateNetworkProfile")
CreateProject = Action("CreateProject")
CreateRemoteAccessSession = Action("CreateRemoteAccessSession")
CreateTestGridProject = Action("CreateTestGridProject")
CreateTestGridUrl = Action("CreateTestGridUrl")
CreateUpload = Action("CreateUpload")
CreateVPCEConfiguration = Action("CreateVPCEConfiguration")
DeleteDevicePool = Action("DeleteDevicePool")
DeleteInstanceProfile = Action("DeleteInstanceProfile")
DeleteNetworkProfile = Action("DeleteNetworkProfile")
DeleteProject = Action("DeleteProject")
DeleteRemoteAccessSession = Action("DeleteRemoteAccessSession")
DeleteRun = Action("DeleteRun")
DeleteTestGridProject = Action("DeleteTestGridProject")
DeleteUpload = Action("DeleteUpload")
DeleteVPCEConfiguration = Action("DeleteVPCEConfiguration")
GetAccountSettings = Action("GetAccountSettings")
GetDevice = Action("GetDevice")
GetDeviceInstance = Action("GetDeviceInstance")
GetDevicePool = Action("GetDevicePool")
GetDevicePoolCompatibility = Action("GetDevicePoolCompatibility")
GetInstanceProfile = Action("GetInstanceProfile")
GetJob = Action("GetJob")
GetNetworkProfile = Action("GetNetworkProfile")
GetOfferingStatus = Action("GetOfferingStatus")
GetProject = Action("GetProject")
GetRemoteAccessSession = Action("GetRemoteAccessSession")
GetRun = Action("GetRun")
GetSuite = Action("GetSuite")
GetTest = Action("GetTest")
GetTestGridProject = Action("GetTestGridProject")
GetTestGridSession = Action("GetTestGridSession")
GetUpload = Action("GetUpload")
GetVPCEConfiguration = Action("GetVPCEConfiguration")
InstallToRemoteAccessSession = Action("InstallToRemoteAccessSession")
ListArtifacts = Action("ListArtifacts")
ListDeviceInstances = Action("ListDeviceInstances")
ListDevicePools = Action("ListDevicePools")
ListDevices = Action("ListDevices")
ListInstanceProfiles = Action("ListInstanceProfiles")
ListJobs = Action("ListJobs")
ListNetworkProfiles = Action("ListNetworkProfiles")
ListOfferingPromotions = Action("ListOfferingPromotions")
ListOfferingTransactions = Action("ListOfferingTransactions")
ListOfferings = Action("ListOfferings")
ListProjects = Action("ListProjects")
ListRemoteAccessSessions = Action("ListRemoteAccessSessions")
ListRuns = Action("ListRuns")
ListSamples = Action("ListSamples")
ListSuites = Action("ListSuites")
ListTagsForResource = Action("ListTagsForResource")
ListTestGridProjects = Action("ListTestGridProjects")
ListTestGridSessionActions = Action("ListTestGridSessionActions")
ListTestGridSessionArtifacts = Action("ListTestGridSessionArtifacts")
ListTestGridSessions = Action("ListTestGridSessions")
ListTests = Action("ListTests")
ListUniqueProblems = Action("ListUniqueProblems")
ListUploads = Action("ListUploads")
ListVPCEConfigurations = Action("ListVPCEConfigurations")
PurchaseOffering = Action("PurchaseOffering")
RenewOffering = Action("RenewOffering")
ScheduleRun = Action("ScheduleRun")
StopJob = Action("StopJob")
StopRemoteAccessSession = Action("StopRemoteAccessSession")
StopRun = Action("StopRun")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDeviceInstance = Action("UpdateDeviceInstance")
UpdateDevicePool = Action("UpdateDevicePool")
UpdateInstanceProfile = Action("UpdateInstanceProfile")
UpdateNetworkProfile = Action("UpdateNetworkProfile")
UpdateProject = Action("UpdateProject")
UpdateTestGridProject = Action("UpdateTestGridProject")
UpdateUpload = Action("UpdateUpload")
UpdateVPCEConfiguration = Action("UpdateVPCEConfiguration")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Network Manager"
prefix = "networkmanager"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateCustomerGateway = Action("AssociateCustomerGateway")
AssociateLink = Action("AssociateLink")
AssociateTransitGatewayConnectPeer = Action("AssociateTransitGatewayConnectPeer")
CreateConnection = Action("CreateConnection")
CreateDevice = Action("CreateDevice")
CreateGlobalNetwork = Action("CreateGlobalNetwork")
CreateLink = Action("CreateLink")
CreateSite = Action("CreateSite")
DeleteConnection = Action("DeleteConnection")
DeleteDevice = Action("DeleteDevice")
DeleteGlobalNetwork = Action("DeleteGlobalNetwork")
DeleteLink = Action("DeleteLink")
DeleteSite = Action("DeleteSite")
DeregisterTransitGateway = Action("DeregisterTransitGateway")
DescribeGlobalNetworks = Action("DescribeGlobalNetworks")
DisassociateCustomerGateway = Action("DisassociateCustomerGateway")
DisassociateLink = Action("DisassociateLink")
DisassociateTransitGatewayConnectPeer = Action("DisassociateTransitGatewayConnectPeer")
GetConnections = Action("GetConnections")
GetCustomerGatewayAssociations = Action("GetCustomerGatewayAssociations")
GetDevices = Action("GetDevices")
GetLinkAssociations = Action("GetLinkAssociations")
GetLinks = Action("GetLinks")
GetSites = Action("GetSites")
GetTransitGatewayConnectPeerAssociations = Action(
    "GetTransitGatewayConnectPeerAssociations"
)
GetTransitGatewayRegistrations = Action("GetTransitGatewayRegistrations")
ListTagsForResource = Action("ListTagsForResource")
RegisterTransitGateway = Action("RegisterTransitGateway")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateConnection = Action("UpdateConnection")
UpdateDevice = Action("UpdateDevice")
UpdateGlobalNetwork = Action("UpdateGlobalNetwork")
UpdateLink = Action("UpdateLink")
UpdateSite = Action("UpdateSite")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon GuardDuty"
prefix = "guardduty"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptInvitation = Action("AcceptInvitation")
ArchiveFindings = Action("ArchiveFindings")
CreateDetector = Action("CreateDetector")
CreateFilter = Action("CreateFilter")
CreateIPSet = Action("CreateIPSet")
CreateMembers = Action("CreateMembers")
CreatePublishingDestination = Action("CreatePublishingDestination")
CreateSampleFindings = Action("CreateSampleFindings")
CreateThreatIntelSet = Action("CreateThreatIntelSet")
DeclineInvitations = Action("DeclineInvitations")
DeleteDetector = Action("DeleteDetector")
DeleteFilter = Action("DeleteFilter")
DeleteIPSet = Action("DeleteIPSet")
DeleteInvitations = Action("DeleteInvitations")
DeleteMembers = Action("DeleteMembers")
DeletePublishingDestination = Action("DeletePublishingDestination")
DeleteThreatIntelSet = Action("DeleteThreatIntelSet")
DescribeOrganizationConfiguration = Action("DescribeOrganizationConfiguration")
DescribePublishingDestination = Action("DescribePublishingDestination")
DisableOrganizationAdminAccount = Action("DisableOrganizationAdminAccount")
DisassociateFromMasterAccount = Action("DisassociateFromMasterAccount")
DisassociateMembers = Action("DisassociateMembers")
EnableOrganizationAdminAccount = Action("EnableOrganizationAdminAccount")
GetDetector = Action("GetDetector")
GetFilter = Action("GetFilter")
GetFindings = Action("GetFindings")
GetFindingsStatistics = Action("GetFindingsStatistics")
GetIPSet = Action("GetIPSet")
GetInvitationsCount = Action("GetInvitationsCount")
GetMasterAccount = Action("GetMasterAccount")
GetMemberDetectors = Action("GetMemberDetectors")
GetMembers = Action("GetMembers")
GetThreatIntelSet = Action("GetThreatIntelSet")
GetUsageStatistics = Action("GetUsageStatistics")
InviteMembers = Action("InviteMembers")
ListDetectors = Action("ListDetectors")
ListFilters = Action("ListFilters")
ListFindings = Action("ListFindings")
ListIPSets = Action("ListIPSets")
ListInvitations = Action("ListInvitations")
ListMembers = Action("ListMembers")
ListOrganizationAdminAccounts = Action("ListOrganizationAdminAccounts")
ListPublishingDestinations = Action("ListPublishingDestinations")
ListTagsForResource = Action("ListTagsForResource")
ListThreatIntelSets = Action("ListThreatIntelSets")
StartMonitoringMembers = Action("StartMonitoringMembers")
StopMonitoringMembers = Action("StopMonitoringMembers")
TagResource = Action("TagResource")
UnarchiveFindings = Action("UnarchiveFindings")
UntagResource = Action("UntagResource")
UpdateDetector = Action("UpdateDetector")
UpdateFilter = Action("UpdateFilter")
UpdateFindingsFeedback = Action("UpdateFindingsFeedback")
UpdateIPSet = Action("UpdateIPSet")
UpdateMemberDetectors = Action("UpdateMemberDetectors")
UpdateOrganizationConfiguration = Action("UpdateOrganizationConfiguration")
UpdatePublishingDestination = Action("UpdatePublishingDestination")
UpdateThreatIntelSet = Action("UpdateThreatIntelSet")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Elastic Beanstalk"
prefix = "elasticbeanstalk"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AbortEnvironmentUpdate = Action("AbortEnvironmentUpdate")
AddTags = Action("AddTags")
ApplyEnvironmentManagedAction = Action("ApplyEnvironmentManagedAction")
AssociateEnvironmentOperationsRole = Action("AssociateEnvironmentOperationsRole")
CheckDNSAvailability = Action("CheckDNSAvailability")
ComposeEnvironments = Action("ComposeEnvironments")
CreateApplication = Action("CreateApplication")
CreateApplicationVersion = Action("CreateApplicationVersion")
CreateConfigurationTemplate = Action("CreateConfigurationTemplate")
CreateEnvironment = Action("CreateEnvironment")
CreatePlatformVersion = Action("CreatePlatformVersion")
CreateStorageLocation = Action("CreateStorageLocation")
DeleteApplication = Action("DeleteApplication")
DeleteApplicationVersion = Action("DeleteApplicationVersion")
DeleteConfigurationTemplate = Action("DeleteConfigurationTemplate")
DeleteEnvironmentConfiguration = Action("DeleteEnvironmentConfiguration")
DeletePlatformVersion = Action("DeletePlatformVersion")
DescribeAccountAttributes = Action("DescribeAccountAttributes")
DescribeApplicationVersions = Action("DescribeApplicationVersions")
DescribeApplications = Action("DescribeApplications")
DescribeConfigurationOptions = Action("DescribeConfigurationOptions")
DescribeConfigurationSettings = Action("DescribeConfigurationSettings")
DescribeEnvironmentHealth = Action("DescribeEnvironmentHealth")
DescribeEnvironmentManagedActionHistory = Action(
    "DescribeEnvironmentManagedActionHistory"
)
DescribeEnvironmentManagedActions = Action("DescribeEnvironmentManagedActions")
DescribeEnvironmentResources = Action("DescribeEnvironmentResources")
DescribeEnvironments = Action("DescribeEnvironments")
DescribeEvents = Action("DescribeEvents")
DescribeInstancesHealth = Action("DescribeInstancesHealth")
DescribePlatformVersion = Action("DescribePlatformVersion")
DisassociateEnvironmentOperationsRole = Action("DisassociateEnvironmentOperationsRole")
ListAvailableSolutionStacks = Action("ListAvailableSolutionStacks")
ListPlatformBranches = Action("ListPlatformBranches")
ListPlatformVersions = Action("ListPlatformVersions")
ListTagsForResource = Action("ListTagsForResource")
PutInstanceStatistics = Action("PutInstanceStatistics")
RebuildEnvironment = Action("RebuildEnvironment")
RemoveTags = Action("RemoveTags")
RequestEnvironmentInfo = Action("RequestEnvironmentInfo")
RestartAppServer = Action("RestartAppServer")
RetrieveEnvironmentInfo = Action("RetrieveEnvironmentInfo")
SwapEnvironmentCNAMEs = Action("SwapEnvironmentCNAMEs")
TerminateEnvironment = Action("TerminateEnvironment")
UpdateApplication = Action("UpdateApplication")
UpdateApplicationResourceLifecycle = Action("UpdateApplicationResourceLifecycle")
UpdateApplicationVersion = Action("UpdateApplicationVersion")
UpdateConfigurationTemplate = Action("UpdateConfigurationTemplate")
UpdateEnvironment = Action("UpdateEnvironment")
UpdateTagsForResource = Action("UpdateTagsForResource")
ValidateConfigurationSettings = Action("ValidateConfigurationSettings")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Monitron"
prefix = "monitron"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateProjectAdminUser = Action("AssociateProjectAdminUser")
CreateProject = Action("CreateProject")
DeleteProject = Action("DeleteProject")
DisassociateProjectAdminUser = Action("DisassociateProjectAdminUser")
GetProject = Action("GetProject")
GetProjectAdminUser = Action("GetProjectAdminUser")
ListProjectAdminUsers = Action("ListProjectAdminUsers")
ListProjects = Action("ListProjects")
ListTagsForResource = Action("ListTagsForResource")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateProject = Action("UpdateProject")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Elemental MediaTailor"
prefix = "mediatailor"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateChannel = Action("CreateChannel")
CreateProgram = Action("CreateProgram")
CreateSourceLocation = Action("CreateSourceLocation")
CreateVodSource = Action("CreateVodSource")
DeleteChannel = Action("DeleteChannel")
DeleteChannelPolicy = Action("DeleteChannelPolicy")
DeletePlaybackConfiguration = Action("DeletePlaybackConfiguration")
DeleteProgram = Action("DeleteProgram")
DeleteSourceLocation = Action("DeleteSourceLocation")
DeleteVodSource = Action("DeleteVodSource")
DescribeChannel = Action("DescribeChannel")
DescribeProgram = Action("DescribeProgram")
DescribeSourceLocation = Action("DescribeSourceLocation")
DescribeVodSource = Action("DescribeVodSource")
GetChannelPolicy = Action("GetChannelPolicy")
GetChannelSchedule = Action("GetChannelSchedule")
GetPlaybackConfiguration = Action("GetPlaybackConfiguration")
ListAlerts = Action("ListAlerts")
ListChannels = Action("ListChannels")
ListPlaybackConfigurations = Action("ListPlaybackConfigurations")
ListSourceLocations = Action("ListSourceLocations")
ListTagsForResource = Action("ListTagsForResource")
ListVodSources = Action("ListVodSources")
PutChannelPolicy = Action("PutChannelPolicy")
PutPlaybackConfiguration = Action("PutPlaybackConfiguration")
StartChannel = Action("StartChannel")
StopChannel = Action("StopChannel")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateChannel = Action("UpdateChannel")
UpdateSourceLocation = Action("UpdateSourceLocation")
UpdateVodSource = Action("UpdateVodSource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Connect Customer Profiles"
prefix = "profile"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddProfileKey = Action("AddProfileKey")
CreateDomain = Action("CreateDomain")
CreateProfile = Action("CreateProfile")
DeleteDomain = Action("DeleteDomain")
DeleteIntegration = Action("DeleteIntegration")
DeleteProfile = Action("DeleteProfile")
DeleteProfileKey = Action("DeleteProfileKey")
DeleteProfileObject = Action("DeleteProfileObject")
DeleteProfileObjectType = Action("DeleteProfileObjectType")
GetDomain = Action("GetDomain")
GetIntegration = Action("GetIntegration")
GetMatches = Action("GetMatches")
GetProfileObjectType = Action("GetProfileObjectType")
GetProfileObjectTypeTemplate = Action("GetProfileObjectTypeTemplate")
ListAccountIntegrations = Action("ListAccountIntegrations")
ListDomains = Action("ListDomains")
ListIntegrations = Action("ListIntegrations")
ListProfileObjectTypeTemplates = Action("ListProfileObjectTypeTemplates")
ListProfileObjectTypes = Action("ListProfileObjectTypes")
ListProfileObjects = Action("ListProfileObjects")
ListTagsForResource = Action("ListTagsForResource")
MergeProfiles = Action("MergeProfiles")
PutIntegration = Action("PutIntegration")
PutProfileObject = Action("PutProfileObject")
PutProfileObjectType = Action("PutProfileObjectType")
SearchProfiles = Action("SearchProfiles")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDomain = Action("UpdateDomain")
UpdateProfile = Action("UpdateProfile")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Support"
prefix = "support"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddAttachmentsToSet = Action("AddAttachmentsToSet")
AddCommunicationToCase = Action("AddCommunicationToCase")
CreateCase = Action("CreateCase")
DescribeAttachment = Action("DescribeAttachment")
DescribeCaseAttributes = Action("DescribeCaseAttributes")
DescribeCases = Action("DescribeCases")
DescribeCommunications = Action("DescribeCommunications")
DescribeIssueTypes = Action("DescribeIssueTypes")
DescribeServices = Action("DescribeServices")
DescribeSeverityLevels = Action("DescribeSeverityLevels")
DescribeSupportLevel = Action("DescribeSupportLevel")
DescribeTrustedAdvisorCheckRefreshStatuses = Action(
    "DescribeTrustedAdvisorCheckRefreshStatuses"
)
DescribeTrustedAdvisorCheckResult = Action("DescribeTrustedAdvisorCheckResult")
DescribeTrustedAdvisorCheckSummaries = Action("DescribeTrustedAdvisorCheckSummaries")
DescribeTrustedAdvisorChecks = Action("DescribeTrustedAdvisorChecks")
InitiateCallForCase = Action("InitiateCallForCase")
InitiateChatForCase = Action("InitiateChatForCase")
PutCaseAttributes = Action("PutCaseAttributes")
RateCaseCommunication = Action("RateCaseCommunication")
RefreshTrustedAdvisorCheck = Action("RefreshTrustedAdvisorCheck")
ResolveCase = Action("ResolveCase")
SearchForCases = Action("SearchForCases")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon RDS"
prefix = "rds"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddRoleToDBCluster = Action("AddRoleToDBCluster")
AddRoleToDBInstance = Action("AddRoleToDBInstance")
AddSourceIdentifierToSubscription = Action("AddSourceIdentifierToSubscription")
AddTagsToResource = Action("AddTagsToResource")
ApplyPendingMaintenanceAction = Action("ApplyPendingMaintenanceAction")
AuthorizeDBSecurityGroupIngress = Action("AuthorizeDBSecurityGroupIngress")
BacktrackDBCluster = Action("BacktrackDBCluster")
CancelExportTask = Action("CancelExportTask")
CopyDBClusterParameterGroup = Action("CopyDBClusterParameterGroup")
CopyDBClusterSnapshot = Action("CopyDBClusterSnapshot")
CopyDBParameterGroup = Action("CopyDBParameterGroup")
CopyDBSnapshot = Action("CopyDBSnapshot")
CopyOptionGroup = Action("CopyOptionGroup")
CreateCustomAvailabilityZone = Action("CreateCustomAvailabilityZone")
CreateDBCluster = Action("CreateDBCluster")
CreateDBClusterEndpoint = Action("CreateDBClusterEndpoint")
CreateDBClusterParameterGroup = Action("CreateDBClusterParameterGroup")
CreateDBClusterSnapshot = Action("CreateDBClusterSnapshot")
CreateDBInstance = Action("CreateDBInstance")
CreateDBInstanceReadReplica = Action("CreateDBInstanceReadReplica")
CreateDBParameterGroup = Action("CreateDBParameterGroup")
CreateDBProxy = Action("CreateDBProxy")
CreateDBProxyEndpoint = Action("CreateDBProxyEndpoint")
CreateDBSecurityGroup = Action("CreateDBSecurityGroup")
CreateDBSnapshot = Action("CreateDBSnapshot")
CreateDBSubnetGroup = Action("CreateDBSubnetGroup")
CreateEventSubscription = Action("CreateEventSubscription")
CreateGlobalCluster = Action("CreateGlobalCluster")
CreateOptionGroup = Action("CreateOptionGroup")
CrossRegionCommunication = Action("CrossRegionCommunication")
DeleteCustomAvailabilityZone = Action("DeleteCustomAvailabilityZone")
DeleteDBCluster = Action("DeleteDBCluster")
DeleteDBClusterEndpoint = Action("DeleteDBClusterEndpoint")
DeleteDBClusterParameterGroup = Action("DeleteDBClusterParameterGroup")
DeleteDBClusterSnapshot = Action("DeleteDBClusterSnapshot")
DeleteDBInstance = Action("DeleteDBInstance")
DeleteDBInstanceAutomatedBackup = Action("DeleteDBInstanceAutomatedBackup")
DeleteDBParameterGroup = Action("DeleteDBParameterGroup")
DeleteDBProxy = Action("DeleteDBProxy")
DeleteDBProxyEndpoint = Action("DeleteDBProxyEndpoint")
DeleteDBSecurityGroup = Action("DeleteDBSecurityGroup")
DeleteDBSnapshot = Action("DeleteDBSnapshot")
DeleteDBSubnetGroup = Action("DeleteDBSubnetGroup")
DeleteEventSubscription = Action("DeleteEventSubscription")
DeleteGlobalCluster = Action("DeleteGlobalCluster")
DeleteInstallationMedia = Action("DeleteInstallationMedia")
DeleteOptionGroup = Action("DeleteOptionGroup")
DeregisterDBProxyTargets = Action("DeregisterDBProxyTargets")
DescribeAccountAttributes = Action("DescribeAccountAttributes")
DescribeCertificates = Action("DescribeCertificates")
DescribeCustomAvailabilityZones = Action("DescribeCustomAvailabilityZones")
DescribeDBClusterBacktracks = Action("DescribeDBClusterBacktracks")
DescribeDBClusterEndpoints = Action("DescribeDBClusterEndpoints")
DescribeDBClusterParameterGroups = Action("DescribeDBClusterParameterGroups")
DescribeDBClusterParameters = Action("DescribeDBClusterParameters")
DescribeDBClusterSnapshotAttributes = Action("DescribeDBClusterSnapshotAttributes")
DescribeDBClusterSnapshots = Action("DescribeDBClusterSnapshots")
DescribeDBClusters = Action("DescribeDBClusters")
DescribeDBEngineVersions = Action("DescribeDBEngineVersions")
DescribeDBInstanceAutomatedBackups = Action("DescribeDBInstanceAutomatedBackups")
DescribeDBInstances = Action("DescribeDBInstances")
DescribeDBLogFiles = Action("DescribeDBLogFiles")
DescribeDBParameterGroups = Action("DescribeDBParameterGroups")
DescribeDBParameters = Action("DescribeDBParameters")
DescribeDBProxies = Action("DescribeDBProxies")
DescribeDBProxyEndpoints = Action("DescribeDBProxyEndpoints")
DescribeDBProxyTargetGroups = Action("DescribeDBProxyTargetGroups")
DescribeDBProxyTargets = Action("DescribeDBProxyTargets")
DescribeDBSecurityGroups = Action("DescribeDBSecurityGroups")
DescribeDBSnapshotAttributes = Action("DescribeDBSnapshotAttributes")
DescribeDBSnapshots = Action("DescribeDBSnapshots")
DescribeDBSubnetGroups = Action("DescribeDBSubnetGroups")
DescribeEngineDefaultClusterParameters = Action(
    "DescribeEngineDefaultClusterParameters"
)
DescribeEngineDefaultParameters = Action("DescribeEngineDefaultParameters")
DescribeEventCategories = Action("DescribeEventCategories")
DescribeEventSubscriptions = Action("DescribeEventSubscriptions")
DescribeEvents = Action("DescribeEvents")
DescribeExportTasks = Action("DescribeExportTasks")
DescribeGlobalClusters = Action("DescribeGlobalClusters")
DescribeInstallationMedia = Action("DescribeInstallationMedia")
DescribeOptionGroupOptions = Action("DescribeOptionGroupOptions")
DescribeOptionGroups = Action("DescribeOptionGroups")
DescribeOrderableDBInstanceOptions = Action("DescribeOrderableDBInstanceOptions")
DescribePendingMaintenanceActions = Action("DescribePendingMaintenanceActions")
DescribeRecommendationGroups = Action("DescribeRecommendationGroups")
DescribeRecommendations = Action("DescribeRecommendations")
DescribeReservedDBInstances = Action("DescribeReservedDBInstances")
DescribeReservedDBInstancesOfferings = Action("DescribeReservedDBInstancesOfferings")
DescribeSourceRegions = Action("DescribeSourceRegions")
DescribeValidDBInstanceModifications = Action("DescribeValidDBInstanceModifications")
DownloadCompleteDBLogFile = Action("DownloadCompleteDBLogFile")
DownloadDBLogFilePortion = Action("DownloadDBLogFilePortion")
FailoverDBCluster = Action("FailoverDBCluster")
FailoverGlobalCluster = Action("FailoverGlobalCluster")
ImportInstallationMedia = Action("ImportInstallationMedia")
ListTagsForResource = Action("ListTagsForResource")
ModifyCertificates = Action("ModifyCertificates")
ModifyCurrentDBClusterCapacity = Action("ModifyCurrentDBClusterCapacity")
ModifyDBCluster = Action("ModifyDBCluster")
ModifyDBClusterEndpoint = Action("ModifyDBClusterEndpoint")
ModifyDBClusterParameterGroup = Action("ModifyDBClusterParameterGroup")
ModifyDBClusterSnapshotAttribute = Action("ModifyDBClusterSnapshotAttribute")
ModifyDBInstance = Action("ModifyDBInstance")
ModifyDBParameterGroup = Action("ModifyDBParameterGroup")
ModifyDBProxy = Action("ModifyDBProxy")
ModifyDBProxyEndpoint = Action("ModifyDBProxyEndpoint")
ModifyDBProxyTargetGroup = Action("ModifyDBProxyTargetGroup")
ModifyDBSnapshot = Action("ModifyDBSnapshot")
ModifyDBSnapshotAttribute = Action("ModifyDBSnapshotAttribute")
ModifyDBSubnetGroup = Action("ModifyDBSubnetGroup")
ModifyEventSubscription = Action("ModifyEventSubscription")
ModifyGlobalCluster = Action("ModifyGlobalCluster")
ModifyOptionGroup = Action("ModifyOptionGroup")
ModifyRecommendation = Action("ModifyRecommendation")
PromoteReadReplica = Action("PromoteReadReplica")
PromoteReadReplicaDBCluster = Action("PromoteReadReplicaDBCluster")
PurchaseReservedDBInstancesOffering = Action("PurchaseReservedDBInstancesOffering")
RebootDBInstance = Action("RebootDBInstance")
RegisterDBProxyTargets = Action("RegisterDBProxyTargets")
RemoveFromGlobalCluster = Action("RemoveFromGlobalCluster")
RemoveRoleFromDBCluster = Action("RemoveRoleFromDBCluster")
RemoveRoleFromDBInstance = Action("RemoveRoleFromDBInstance")
RemoveSourceIdentifierFromSubscription = Action(
    "RemoveSourceIdentifierFromSubscription"
)
RemoveTagsFromResource = Action("RemoveTagsFromResource")
ResetDBClusterParameterGroup = Action("ResetDBClusterParameterGroup")
ResetDBParameterGroup = Action("ResetDBParameterGroup")
RestoreDBClusterFromS3 = Action("RestoreDBClusterFromS3")
RestoreDBClusterFromSnapshot = Action("RestoreDBClusterFromSnapshot")
RestoreDBClusterToPointInTime = Action("RestoreDBClusterToPointInTime")
RestoreDBInstanceFromDBSnapshot = Action("RestoreDBInstanceFromDBSnapshot")
RestoreDBInstanceFromS3 = Action("RestoreDBInstanceFromS3")
RestoreDBInstanceToPointInTime = Action("RestoreDBInstanceToPointInTime")
RevokeDBSecurityGroupIngress = Action("RevokeDBSecurityGroupIngress")
StartActivityStream = Action("StartActivityStream")
StartDBCluster = Action("StartDBCluster")
StartDBInstance = Action("StartDBInstance")
StartDBInstanceAutomatedBackupsReplication = Action(
    "StartDBInstanceAutomatedBackupsReplication"
)
StartExportTask = Action("StartExportTask")
StopActivityStream = Action("StopActivityStream")
StopDBCluster = Action("StopDBCluster")
StopDBInstance = Action("StopDBInstance")
StopDBInstanceAutomatedBackupsReplication = Action(
    "StopDBInstanceAutomatedBackupsReplication"
)



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Cloud Map"
prefix = "servicediscovery"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateHttpNamespace = Action("CreateHttpNamespace")
CreatePrivateDnsNamespace = Action("CreatePrivateDnsNamespace")
CreatePublicDnsNamespace = Action("CreatePublicDnsNamespace")
CreateService = Action("CreateService")
DeleteNamespace = Action("DeleteNamespace")
DeleteService = Action("DeleteService")
DeregisterInstance = Action("DeregisterInstance")
DiscoverInstances = Action("DiscoverInstances")
GetInstance = Action("GetInstance")
GetInstancesHealthStatus = Action("GetInstancesHealthStatus")
GetNamespace = Action("GetNamespace")
GetOperation = Action("GetOperation")
GetService = Action("GetService")
ListInstances = Action("ListInstances")
ListNamespaces = Action("ListNamespaces")
ListOperations = Action("ListOperations")
ListServices = Action("ListServices")
ListTagsForResource = Action("ListTagsForResource")
RegisterInstance = Action("RegisterInstance")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateHttpNamespace = Action("UpdateHttpNamespace")
UpdateInstanceCustomHealthStatus = Action("UpdateInstanceCustomHealthStatus")
UpdateInstanceHeartbeatStatus = Action("UpdateInstanceHeartbeatStatus")
UpdatePrivateDnsNamespace = Action("UpdatePrivateDnsNamespace")
UpdatePublicDnsNamespace = Action("UpdatePublicDnsNamespace")
UpdateService = Action("UpdateService")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Elemental MediaPackage"
prefix = "mediapackage"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ConfigureLogs = Action("ConfigureLogs")
CreateChannel = Action("CreateChannel")
CreateHarvestJob = Action("CreateHarvestJob")
CreateOriginEndpoint = Action("CreateOriginEndpoint")
DeleteChannel = Action("DeleteChannel")
DeleteOriginEndpoint = Action("DeleteOriginEndpoint")
DescribeChannel = Action("DescribeChannel")
DescribeHarvestJob = Action("DescribeHarvestJob")
DescribeOriginEndpoint = Action("DescribeOriginEndpoint")
ListChannels = Action("ListChannels")
ListHarvestJobs = Action("ListHarvestJobs")
ListOriginEndpoints = Action("ListOriginEndpoints")
ListTagsForResource = Action("ListTagsForResource")
RotateChannelCredentials = Action("RotateChannelCredentials")
RotateIngestEndpointCredentials = Action("RotateIngestEndpointCredentials")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateChannel = Action("UpdateChannel")
UpdateOriginEndpoint = Action("UpdateOriginEndpoint")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS DeepRacer"
prefix = "deepracer"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddLeaderboardAccessPermission = Action("AddLeaderboardAccessPermission")
AdminGetAccountConfig = Action("AdminGetAccountConfig")
AdminListAssociatedResources = Action("AdminListAssociatedResources")
AdminListAssociatedUsers = Action("AdminListAssociatedUsers")
AdminManageUser = Action("AdminManageUser")
AdminSetAccountConfig = Action("AdminSetAccountConfig")
CloneReinforcementLearningModel = Action("CloneReinforcementLearningModel")
CreateAccountResources = Action("CreateAccountResources")
CreateCar = Action("CreateCar")
CreateLeaderboard = Action("CreateLeaderboard")
CreateLeaderboardAccessToken = Action("CreateLeaderboardAccessToken")
CreateLeaderboardSubmission = Action("CreateLeaderboardSubmission")
CreateReinforcementLearningModel = Action("CreateReinforcementLearningModel")
DeleteAccountResources = Action("DeleteAccountResources")
DeleteLeaderboard = Action("DeleteLeaderboard")
DeleteModel = Action("DeleteModel")
EditLeaderboard = Action("EditLeaderboard")
GetAccountConfig = Action("GetAccountConfig")
GetAccountResources = Action("GetAccountResources")
GetAlias = Action("GetAlias")
GetAssetUrl = Action("GetAssetUrl")
GetCar = Action("GetCar")
GetCars = Action("GetCars")
GetEvaluation = Action("GetEvaluation")
GetLatestUserSubmission = Action("GetLatestUserSubmission")
GetLeaderboard = Action("GetLeaderboard")
GetModel = Action("GetModel")
GetPrivateLeaderboard = Action("GetPrivateLeaderboard")
GetRankedUserSubmission = Action("GetRankedUserSubmission")
GetTrack = Action("GetTrack")
GetTrainingJob = Action("GetTrainingJob")
ImportModel = Action("ImportModel")
ListEvaluations = Action("ListEvaluations")
ListLeaderboardSubmissions = Action("ListLeaderboardSubmissions")
ListLeaderboards = Action("ListLeaderboards")
ListModels = Action("ListModels")
ListPrivateLeaderboardParticipants = Action("ListPrivateLeaderboardParticipants")
ListPrivateLeaderboards = Action("ListPrivateLeaderboards")
ListSubscribedPrivateLeaderboards = Action("ListSubscribedPrivateLeaderboards")
ListTagsForResource = Action("ListTagsForResource")
ListTracks = Action("ListTracks")
ListTrainingJobs = Action("ListTrainingJobs")
MigrateModels = Action("MigrateModels")
PerformLeaderboardOperation = Action("PerformLeaderboardOperation")
RemoveLeaderboardAccessPermission = Action("RemoveLeaderboardAccessPermission")
SetAlias = Action("SetAlias")
StartEvaluation = Action("StartEvaluation")
StopEvaluation = Action("StopEvaluation")
StopTrainingReinforcementLearningModel = Action(
    "StopTrainingReinforcementLearningModel"
)
TagResource = Action("TagResource")
TestRewardFunction = Action("TestRewardFunction")
UntagResource = Action("UntagResource")
UpdateCar = Action("UpdateCar")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS CodePipeline"
prefix = "codepipeline"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcknowledgeJob = Action("AcknowledgeJob")
AcknowledgeThirdPartyJob = Action("AcknowledgeThirdPartyJob")
CreateCustomActionType = Action("CreateCustomActionType")
CreatePipeline = Action("CreatePipeline")
DeleteCustomActionType = Action("DeleteCustomActionType")
DeletePipeline = Action("DeletePipeline")
DeleteWebhook = Action("DeleteWebhook")
DeregisterWebhookWithThirdParty = Action("DeregisterWebhookWithThirdParty")
DisableStageTransition = Action("DisableStageTransition")
EnableStageTransition = Action("EnableStageTransition")
GetActionType = Action("GetActionType")
GetJobDetails = Action("GetJobDetails")
GetPipeline = Action("GetPipeline")
GetPipelineExecution = Action("GetPipelineExecution")
GetPipelineState = Action("GetPipelineState")
GetThirdPartyJobDetails = Action("GetThirdPartyJobDetails")
ListActionExecutions = Action("ListActionExecutions")
ListActionTypes = Action("ListActionTypes")
ListPipelineExecutions = Action("ListPipelineExecutions")
ListPipelines = Action("ListPipelines")
ListTagsForResource = Action("ListTagsForResource")
ListWebhooks = Action("ListWebhooks")
PollForJobs = Action("PollForJobs")
PollForThirdPartyJobs = Action("PollForThirdPartyJobs")
PutActionRevision = Action("PutActionRevision")
PutApprovalResult = Action("PutApprovalResult")
PutJobFailureResult = Action("PutJobFailureResult")
PutJobSuccessResult = Action("PutJobSuccessResult")
PutThirdPartyJobFailureResult = Action("PutThirdPartyJobFailureResult")
PutThirdPartyJobSuccessResult = Action("PutThirdPartyJobSuccessResult")
PutWebhook = Action("PutWebhook")
RegisterWebhookWithThirdParty = Action("RegisterWebhookWithThirdParty")
RetryStageExecution = Action("RetryStageExecution")
StartPipelineExecution = Action("StartPipelineExecution")
StopPipelineExecution = Action("StopPipelineExecution")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateActionType = Action("UpdateActionType")
UpdatePipeline = Action("UpdatePipeline")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS SSO"
prefix = "sso"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddMemberToGroup = Action("AddMemberToGroup")
AssociateDirectory = Action("AssociateDirectory")
AssociateProfile = Action("AssociateProfile")
AttachManagedPolicyToPermissionSet = Action("AttachManagedPolicyToPermissionSet")
CreateAccountAssignment = Action("CreateAccountAssignment")
CreateAlias = Action("CreateAlias")
CreateApplicationInstance = Action("CreateApplicationInstance")
CreateApplicationInstanceCertificate = Action("CreateApplicationInstanceCertificate")
CreateGroup = Action("CreateGroup")
CreateInstanceAccessControlAttributeConfiguration = Action(
    "CreateInstanceAccessControlAttributeConfiguration"
)
CreateManagedApplicationInstance = Action("CreateManagedApplicationInstance")
CreatePermissionSet = Action("CreatePermissionSet")
CreateProfile = Action("CreateProfile")
CreateTrust = Action("CreateTrust")
CreateUser = Action("CreateUser")
DeleteAccountAssignment = Action("DeleteAccountAssignment")
DeleteApplicationInstance = Action("DeleteApplicationInstance")
DeleteApplicationInstanceCertificate = Action("DeleteApplicationInstanceCertificate")
DeleteGroup = Action("DeleteGroup")
DeleteInlinePolicyFromPermissionSet = Action("DeleteInlinePolicyFromPermissionSet")
DeleteInstanceAccessControlAttributeConfiguration = Action(
    "DeleteInstanceAccessControlAttributeConfiguration"
)
DeleteManagedApplicationInstance = Action("DeleteManagedApplicationInstance")
DeletePermissionSet = Action("DeletePermissionSet")
DeletePermissionsPolicy = Action("DeletePermissionsPolicy")
DeleteProfile = Action("DeleteProfile")
DeleteUser = Action("DeleteUser")
DescribeAccountAssignmentCreationStatus = Action(
    "DescribeAccountAssignmentCreationStatus"
)
DescribeAccountAssignmentDeletionStatus = Action(
    "DescribeAccountAssignmentDeletionStatus"
)
DescribeGroups = Action("DescribeGroups")
DescribeInstanceAccessControlAttributeConfiguration = Action(
    "DescribeInstanceAccessControlAttributeConfiguration"
)
DescribePermissionSet = Action("DescribePermissionSet")
DescribePermissionSetProvisioningStatus = Action(
    "DescribePermissionSetProvisioningStatus"
)
DescribePermissionsPolicies = Action("DescribePermissionsPolicies")
DescribeRegisteredRegions = Action("DescribeRegisteredRegions")
DescribeUsers = Action("DescribeUsers")
DetachManagedPolicyFromPermissionSet = Action("DetachManagedPolicyFromPermissionSet")
DisableUser = Action("DisableUser")
DisassociateDirectory = Action("DisassociateDirectory")
DisassociateProfile = Action("DisassociateProfile")
EnableUser = Action("EnableUser")
GetApplicationInstance = Action("GetApplicationInstance")
GetApplicationTemplate = Action("GetApplicationTemplate")
GetInlinePolicyForPermissionSet = Action("GetInlinePolicyForPermissionSet")
GetManagedApplicationInstance = Action("GetManagedApplicationInstance")
GetMfaDeviceManagementForDirectory = Action("GetMfaDeviceManagementForDirectory")
GetPermissionSet = Action("GetPermissionSet")
GetPermissionsPolicy = Action("GetPermissionsPolicy")
GetProfile = Action("GetProfile")
GetSSOConfiguration = Action("GetSSOConfiguration")
GetSSOStatus = Action("GetSSOStatus")
GetSharedSsoConfiguration = Action("GetSharedSsoConfiguration")
GetSsoConfiguration = Action("GetSsoConfiguration")
GetTrust = Action("GetTrust")
GetUserPoolInfo = Action("GetUserPoolInfo")
ImportApplicationInstanceServiceProviderMetadata = Action(
    "ImportApplicationInstanceServiceProviderMetadata"
)
ListAccountAssignmentCreationStatus = Action("ListAccountAssignmentCreationStatus")
ListAccountAssignmentDeletionStatus = Action("ListAccountAssignmentDeletionStatus")
ListAccountAssignments = Action("ListAccountAssignments")
ListAccountsForProvisionedPermissionSet = Action(
    "ListAccountsForProvisionedPermissionSet"
)
ListApplicationInstanceCertificates = Action("ListApplicationInstanceCertificates")
ListApplicationInstances = Action("ListApplicationInstances")
ListApplicationTemplates = Action("ListApplicationTemplates")
ListApplications = Action("ListApplications")
ListDirectoryAssociations = Action("ListDirectoryAssociations")
ListGroupsForUser = Action("ListGroupsForUser")
ListInstances = Action("ListInstances")
ListManagedPoliciesInPermissionSet = Action("ListManagedPoliciesInPermissionSet")
ListMembersInGroup = Action("ListMembersInGroup")
ListPermissionSetProvisioningStatus = Action("ListPermissionSetProvisioningStatus")
ListPermissionSets = Action("ListPermissionSets")
ListPermissionSetsProvisionedToAccount = Action(
    "ListPermissionSetsProvisionedToAccount"
)
ListProfileAssociations = Action("ListProfileAssociations")
ListProfiles = Action("ListProfiles")
ListTagsForResource = Action("ListTagsForResource")
ProvisionPermissionSet = Action("ProvisionPermissionSet")
PutInlinePolicyToPermissionSet = Action("PutInlinePolicyToPermissionSet")
PutMfaDeviceManagementForDirectory = Action("PutMfaDeviceManagementForDirectory")
PutPermissionsPolicy = Action("PutPermissionsPolicy")
RemoveMemberFromGroup = Action("RemoveMemberFromGroup")
SearchGroups = Action("SearchGroups")
SearchUsers = Action("SearchUsers")
SetTemporaryPassword = Action("SetTemporaryPassword")
StartSSO = Action("StartSSO")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateApplicationInstanceActiveCertificate = Action(
    "UpdateApplicationInstanceActiveCertificate"
)
UpdateApplicationInstanceDisplayData = Action("UpdateApplicationInstanceDisplayData")
UpdateApplicationInstanceResponseConfiguration = Action(
    "UpdateApplicationInstanceResponseConfiguration"
)
UpdateApplicationInstanceResponseSchemaConfiguration = Action(
    "UpdateApplicationInstanceResponseSchemaConfiguration"
)
UpdateApplicationInstanceSecurityConfiguration = Action(
    "UpdateApplicationInstanceSecurityConfiguration"
)
UpdateApplicationInstanceServiceProviderConfiguration = Action(
    "UpdateApplicationInstanceServiceProviderConfiguration"
)
UpdateApplicationInstanceStatus = Action("UpdateApplicationInstanceStatus")
UpdateDirectoryAssociation = Action("UpdateDirectoryAssociation")
UpdateGroup = Action("UpdateGroup")
UpdateInstanceAccessControlAttributeConfiguration = Action(
    "UpdateInstanceAccessControlAttributeConfiguration"
)
UpdateManagedApplicationInstanceStatus = Action(
    "UpdateManagedApplicationInstanceStatus"
)
UpdatePermissionSet = Action("UpdatePermissionSet")
UpdateProfile = Action("UpdateProfile")
UpdateSSOConfiguration = Action("UpdateSSOConfiguration")
UpdateTrust = Action("UpdateTrust")
UpdateUser = Action("UpdateUser")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon SQS"
prefix = "sqs"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddPermission = Action("AddPermission")
ChangeMessageVisibility = Action("ChangeMessageVisibility")
ChangeMessageVisibilityBatch = Action("ChangeMessageVisibilityBatch")
CreateQueue = Action("CreateQueue")
DeleteMessage = Action("DeleteMessage")
DeleteMessageBatch = Action("DeleteMessageBatch")
DeleteQueue = Action("DeleteQueue")
GetQueueAttributes = Action("GetQueueAttributes")
GetQueueUrl = Action("GetQueueUrl")
ListDeadLetterSourceQueues = Action("ListDeadLetterSourceQueues")
ListQueueTags = Action("ListQueueTags")
ListQueues = Action("ListQueues")
PurgeQueue = Action("PurgeQueue")
ReceiveMessage = Action("ReceiveMessage")
RemovePermission = Action("RemovePermission")
SendMessage = Action("SendMessage")
SendMessageBatch = Action("SendMessageBatch")
SetQueueAttributes = Action("SetQueueAttributes")
TagQueue = Action("TagQueue")
UntagQueue = Action("UntagQueue")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Ground Station"
prefix = "groundstation"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelContact = Action("CancelContact")
CreateConfig = Action("CreateConfig")
CreateDataflowEndpointGroup = Action("CreateDataflowEndpointGroup")
CreateMissionProfile = Action("CreateMissionProfile")
DeleteConfig = Action("DeleteConfig")
DeleteDataflowEndpointGroup = Action("DeleteDataflowEndpointGroup")
DeleteMissionProfile = Action("DeleteMissionProfile")
DescribeContact = Action("DescribeContact")
GetConfig = Action("GetConfig")
GetDataflowEndpointGroup = Action("GetDataflowEndpointGroup")
GetMinuteUsage = Action("GetMinuteUsage")
GetMissionProfile = Action("GetMissionProfile")
GetSatellite = Action("GetSatellite")
ListConfigs = Action("ListConfigs")
ListContacts = Action("ListContacts")
ListDataflowEndpointGroups = Action("ListDataflowEndpointGroups")
ListGroundStations = Action("ListGroundStations")
ListMissionProfiles = Action("ListMissionProfiles")
ListSatellites = Action("ListSatellites")
ListTagsForResource = Action("ListTagsForResource")
ReserveContact = Action("ReserveContact")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateConfig = Action("UpdateConfig")
UpdateMissionProfile = Action("UpdateMissionProfile")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS AppConfig"
prefix = "appconfig"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateApplication = Action("CreateApplication")
CreateConfigurationProfile = Action("CreateConfigurationProfile")
CreateDeploymentStrategy = Action("CreateDeploymentStrategy")
CreateEnvironment = Action("CreateEnvironment")
CreateHostedConfigurationVersion = Action("CreateHostedConfigurationVersion")
DeleteApplication = Action("DeleteApplication")
DeleteConfigurationProfile = Action("DeleteConfigurationProfile")
DeleteDeploymentStrategy = Action("DeleteDeploymentStrategy")
DeleteEnvironment = Action("DeleteEnvironment")
DeleteHostedConfigurationVersion = Action("DeleteHostedConfigurationVersion")
GetApplication = Action("GetApplication")
GetConfiguration = Action("GetConfiguration")
GetConfigurationProfile = Action("GetConfigurationProfile")
GetDeployment = Action("GetDeployment")
GetDeploymentStrategy = Action("GetDeploymentStrategy")
GetEnvironment = Action("GetEnvironment")
GetHostedConfigurationVersion = Action("GetHostedConfigurationVersion")
ListApplications = Action("ListApplications")
ListConfigurationProfiles = Action("ListConfigurationProfiles")
ListDeploymentStrategies = Action("ListDeploymentStrategies")
ListDeployments = Action("ListDeployments")
ListEnvironments = Action("ListEnvironments")
ListHostedConfigurationVersions = Action("ListHostedConfigurationVersions")
ListTagsForResource = Action("ListTagsForResource")
StartDeployment = Action("StartDeployment")
StopDeployment = Action("StopDeployment")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateApplication = Action("UpdateApplication")
UpdateConfigurationProfile = Action("UpdateConfigurationProfile")
UpdateDeploymentStrategy = Action("UpdateDeploymentStrategy")
UpdateEnvironment = Action("UpdateEnvironment")
ValidateConfiguration = Action("ValidateConfiguration")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Cognito Identity"
prefix = "cognito-identity"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateIdentityPool = Action("CreateIdentityPool")
DeleteIdentities = Action("DeleteIdentities")
DeleteIdentityPool = Action("DeleteIdentityPool")
DescribeIdentity = Action("DescribeIdentity")
DescribeIdentityPool = Action("DescribeIdentityPool")
GetCredentialsForIdentity = Action("GetCredentialsForIdentity")
GetId = Action("GetId")
GetIdentityPoolRoles = Action("GetIdentityPoolRoles")
GetOpenIdToken = Action("GetOpenIdToken")
GetOpenIdTokenForDeveloperIdentity = Action("GetOpenIdTokenForDeveloperIdentity")
GetPrincipalTagAttributeMap = Action("GetPrincipalTagAttributeMap")
ListIdentities = Action("ListIdentities")
ListIdentityPools = Action("ListIdentityPools")
ListTagsForResource = Action("ListTagsForResource")
LookupDeveloperIdentity = Action("LookupDeveloperIdentity")
MergeDeveloperIdentities = Action("MergeDeveloperIdentities")
SetIdentityPoolRoles = Action("SetIdentityPoolRoles")
SetPrincipalTagAttributeMap = Action("SetPrincipalTagAttributeMap")
TagResource = Action("TagResource")
UnlinkDeveloperIdentity = Action("UnlinkDeveloperIdentity")
UnlinkIdentity = Action("UnlinkIdentity")
UntagResource = Action("UntagResource")
UpdateIdentityPool = Action("UpdateIdentityPool")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Transcribe"
prefix = "transcribe"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateCallAnalyticsCategory = Action("CreateCallAnalyticsCategory")
CreateLanguageModel = Action("CreateLanguageModel")
CreateMedicalVocabulary = Action("CreateMedicalVocabulary")
CreateVocabulary = Action("CreateVocabulary")
CreateVocabularyFilter = Action("CreateVocabularyFilter")
DeleteCallAnalyticsCategory = Action("DeleteCallAnalyticsCategory")
DeleteCallAnalyticsJob = Action("DeleteCallAnalyticsJob")
DeleteLanguageModel = Action("DeleteLanguageModel")
DeleteMedicalTranscriptionJob = Action("DeleteMedicalTranscriptionJob")
DeleteMedicalVocabulary = Action("DeleteMedicalVocabulary")
DeleteTranscriptionJob = Action("DeleteTranscriptionJob")
DeleteVocabulary = Action("DeleteVocabulary")
DeleteVocabularyFilter = Action("DeleteVocabularyFilter")
DescribeLanguageModel = Action("DescribeLanguageModel")
GetCallAnalyticsCategory = Action("GetCallAnalyticsCategory")
GetCallAnalyticsJob = Action("GetCallAnalyticsJob")
GetMedicalTranscriptionJob = Action("GetMedicalTranscriptionJob")
GetMedicalVocabulary = Action("GetMedicalVocabulary")
GetTranscriptionJob = Action("GetTranscriptionJob")
GetVocabulary = Action("GetVocabulary")
GetVocabularyFilter = Action("GetVocabularyFilter")
ListCallAnalyticsCategories = Action("ListCallAnalyticsCategories")
ListCallAnalyticsJobs = Action("ListCallAnalyticsJobs")
ListLanguageModels = Action("ListLanguageModels")
ListMedicalTranscriptionJobs = Action("ListMedicalTranscriptionJobs")
ListMedicalVocabularies = Action("ListMedicalVocabularies")
ListTranscriptionJobs = Action("ListTranscriptionJobs")
ListVocabularies = Action("ListVocabularies")
ListVocabularyFilters = Action("ListVocabularyFilters")
StartCallAnalyticsJob = Action("StartCallAnalyticsJob")
StartMedicalStreamTranscription = Action("StartMedicalStreamTranscription")
StartMedicalStreamTranscriptionWebSocket = Action(
    "StartMedicalStreamTranscriptionWebSocket"
)
StartMedicalTranscriptionJob = Action("StartMedicalTranscriptionJob")
StartStreamTranscription = Action("StartStreamTranscription")
StartStreamTranscriptionWebSocket = Action("StartStreamTranscriptionWebSocket")
StartTranscriptionJob = Action("StartTranscriptionJob")
UpdateCallAnalyticsCategory = Action("UpdateCallAnalyticsCategory")
UpdateMedicalVocabulary = Action("UpdateMedicalVocabulary")
UpdateVocabulary = Action("UpdateVocabulary")
UpdateVocabularyFilter = Action("UpdateVocabularyFilter")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Elastic MapReduce"
prefix = "elasticmapreduce"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddInstanceFleet = Action("AddInstanceFleet")
AddInstanceGroups = Action("AddInstanceGroups")
AddJobFlowSteps = Action("AddJobFlowSteps")
AddTags = Action("AddTags")
AttachEditor = Action("AttachEditor")
CancelSteps = Action("CancelSteps")
CreateEditor = Action("CreateEditor")
CreatePersistentAppUI = Action("CreatePersistentAppUI")
CreateRepository = Action("CreateRepository")
CreateSecurityConfiguration = Action("CreateSecurityConfiguration")
CreateStudio = Action("CreateStudio")
CreateStudioPresignedUrl = Action("CreateStudioPresignedUrl")
CreateStudioSessionMapping = Action("CreateStudioSessionMapping")
DeleteEditor = Action("DeleteEditor")
DeleteRepository = Action("DeleteRepository")
DeleteSecurityConfiguration = Action("DeleteSecurityConfiguration")
DeleteStudio = Action("DeleteStudio")
DeleteStudioSessionMapping = Action("DeleteStudioSessionMapping")
DescribeCluster = Action("DescribeCluster")
DescribeEditor = Action("DescribeEditor")
DescribeJobFlows = Action("DescribeJobFlows")
DescribeNotebookExecution = Action("DescribeNotebookExecution")
DescribePersistentAppUI = Action("DescribePersistentAppUI")
DescribeReleaseLabel = Action("DescribeReleaseLabel")
DescribeRepository = Action("DescribeRepository")
DescribeSecurityConfiguration = Action("DescribeSecurityConfiguration")
DescribeStep = Action("DescribeStep")
DescribeStudio = Action("DescribeStudio")
DetachEditor = Action("DetachEditor")
GetBlockPublicAccessConfiguration = Action("GetBlockPublicAccessConfiguration")
GetManagedScalingPolicy = Action("GetManagedScalingPolicy")
GetOnClusterAppUIPresignedURL = Action("GetOnClusterAppUIPresignedURL")
GetPersistentAppUIPresignedURL = Action("GetPersistentAppUIPresignedURL")
GetStudioSessionMapping = Action("GetStudioSessionMapping")
LinkRepository = Action("LinkRepository")
ListBootstrapActions = Action("ListBootstrapActions")
ListClusters = Action("ListClusters")
ListEditors = Action("ListEditors")
ListInstanceFleets = Action("ListInstanceFleets")
ListInstanceGroups = Action("ListInstanceGroups")
ListInstances = Action("ListInstances")
ListNotebookExecutions = Action("ListNotebookExecutions")
ListReleaseLabels = Action("ListReleaseLabels")
ListRepositories = Action("ListRepositories")
ListSecurityConfigurations = Action("ListSecurityConfigurations")
ListSteps = Action("ListSteps")
ListStudioSessionMappings = Action("ListStudioSessionMappings")
ListStudios = Action("ListStudios")
ModifyCluster = Action("ModifyCluster")
ModifyInstanceFleet = Action("ModifyInstanceFleet")
ModifyInstanceGroups = Action("ModifyInstanceGroups")
OpenEditorInConsole = Action("OpenEditorInConsole")
PutAutoScalingPolicy = Action("PutAutoScalingPolicy")
PutBlockPublicAccessConfiguration = Action("PutBlockPublicAccessConfiguration")
PutManagedScalingPolicy = Action("PutManagedScalingPolicy")
RemoveAutoScalingPolicy = Action("RemoveAutoScalingPolicy")
RemoveManagedScalingPolicy = Action("RemoveManagedScalingPolicy")
RemoveTags = Action("RemoveTags")
RunJobFlow = Action("RunJobFlow")
SetTerminationProtection = Action("SetTerminationProtection")
SetVisibleToAllUsers = Action("SetVisibleToAllUsers")
StartEditor = Action("StartEditor")
StartNotebookExecution = Action("StartNotebookExecution")
StopEditor = Action("StopEditor")
StopNotebookExecution = Action("StopNotebookExecution")
TerminateJobFlows = Action("TerminateJobFlows")
UnlinkRepository = Action("UnlinkRepository")
UpdateRepository = Action("UpdateRepository")
UpdateStudio = Action("UpdateStudio")
UpdateStudioSessionMapping = Action("UpdateStudioSessionMapping")
ViewEventsFromAllClustersInConsole = Action("ViewEventsFromAllClustersInConsole")



import json
import unittest

import awacs
from awacs.aws import Action, PolicyDocument


class AWSHelperFn:
    """Mock class to test classes with non-awacs AWSHelperFn parent."""

    def to_json(self, indent=4, sort_keys=True):
        p = self
        return json.dumps(p, cls=awacs.awsencode, indent=indent, sort_keys=sort_keys)

    def __eq__(self, other):
        if isinstance(other, self.__class__):
            return self.to_json() == other.to_json()
        else:
            return False


class AWSHelperFnChild(AWSHelperFn):
    """Child class of non-awacs AWSHelperFn."""

    def __init__(self, **kwargs):
        """Instantiate class."""
        for key, val in kwargs.items():
            setattr(self, key, val)

    def JSONrepr(self):
        """JSON serialization."""
        return self.__dict__


class TypeValidationObject(awacs.AWSProperty):
    """Subclass the AWSObject to test its functionality."""

    props = {"ExpectList": (list, False)}


class TestAWSObject(unittest.TestCase):
    def test_invalid_property(self):
        with self.assertRaises(AttributeError) as exc:
            # statement should be Statement
            PolicyDocument(Version="2012-10-17", statement=[])

        self.assertEqual(
            exc.exception.args[0],
            "'awacs.aws.PolicyDocument' object does not support attribute "
            "'statement'",
        )


class TestAWSProperty(unittest.TestCase):
    def test_prop_value_type_mismatch_expect_list(self):
        class InvalidClass:
            """Class of invalid type."""

        tests_values = ["val", {"key": "val"}, {"val"}, tuple("val"), InvalidClass()]

        for val in tests_values:
            with self.assertRaises(TypeError) as exc:
                TypeValidationObject(ExpectList=val)
            self.assertEqual(
                exc.exception.args[0],
                "ExpectList is %s, expected %s" % (type(val), type(list())),
            )

    def test_prop_value_type_expect_list(self):
        tests_values = [["val"], Action("s3", "*"), AWSHelperFnChild(key="val")]

        for val in tests_values:
            self.assertEqual(TypeValidationObject(ExpectList=val).ExpectList, val)



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Systems Manager Incident Manager"
prefix = "ssm-incidents"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateReplicationSet = Action("CreateReplicationSet")
CreateResponsePlan = Action("CreateResponsePlan")
CreateTimelineEvent = Action("CreateTimelineEvent")
DeleteIncidentRecord = Action("DeleteIncidentRecord")
DeleteReplicationSet = Action("DeleteReplicationSet")
DeleteResourcePolicy = Action("DeleteResourcePolicy")
DeleteResponsePlan = Action("DeleteResponsePlan")
DeleteTimelineEvent = Action("DeleteTimelineEvent")
GetIncidentRecord = Action("GetIncidentRecord")
GetReplicationSet = Action("GetReplicationSet")
GetResourcePolicies = Action("GetResourcePolicies")
GetResponsePlan = Action("GetResponsePlan")
GetTimelineEvent = Action("GetTimelineEvent")
ListIncidentRecords = Action("ListIncidentRecords")
ListRelatedItems = Action("ListRelatedItems")
ListReplicationSets = Action("ListReplicationSets")
ListResponsePlans = Action("ListResponsePlans")
ListTagsForResource = Action("ListTagsForResource")
ListTimelineEvents = Action("ListTimelineEvents")
PutResourcePolicy = Action("PutResourcePolicy")
StartIncident = Action("StartIncident")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDeletionProtection = Action("UpdateDeletionProtection")
UpdateIncidentRecord = Action("UpdateIncidentRecord")
UpdateRelatedItems = Action("UpdateRelatedItems")
UpdateReplicationSet = Action("UpdateReplicationSet")
UpdateResponsePlan = Action("UpdateResponsePlan")
UpdateTimelineEvent = Action("UpdateTimelineEvent")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "High-volume outbound communications"
prefix = "connect-campaigns"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateCampaign = Action("CreateCampaign")
DeleteCampaign = Action("DeleteCampaign")
DescribeCampaign = Action("DescribeCampaign")
GetCampaignState = Action("GetCampaignState")
GetCampaignStateBatch = Action("GetCampaignStateBatch")
ListCampaigns = Action("ListCampaigns")
ListTagsForResource = Action("ListTagsForResource")
PauseCampaign = Action("PauseCampaign")
PutConnectInstanceConfig = Action("PutConnectInstanceConfig")
PutDialRequestBatch = Action("PutDialRequestBatch")
ResumeCampaign = Action("ResumeCampaign")
StartCampaign = Action("StartCampaign")
StopCampaign = Action("StopCampaign")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateCampaignDialerConfig = Action("UpdateCampaignDialerConfig")
UpdateCampaignName = Action("UpdateCampaignName")
UpdateCampaignOutboundCallConfig = Action("UpdateCampaignOutboundCallConfig")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Network Firewall"
prefix = "network-firewall"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateFirewallPolicy = Action("AssociateFirewallPolicy")
AssociateSubnets = Action("AssociateSubnets")
CreateFirewall = Action("CreateFirewall")
CreateFirewallPolicy = Action("CreateFirewallPolicy")
CreateRuleGroup = Action("CreateRuleGroup")
DeleteFirewall = Action("DeleteFirewall")
DeleteFirewallPolicy = Action("DeleteFirewallPolicy")
DeleteResourcePolicy = Action("DeleteResourcePolicy")
DeleteRuleGroup = Action("DeleteRuleGroup")
DescribeFirewall = Action("DescribeFirewall")
DescribeFirewallPolicy = Action("DescribeFirewallPolicy")
DescribeLoggingConfiguration = Action("DescribeLoggingConfiguration")
DescribeResourcePolicy = Action("DescribeResourcePolicy")
DescribeRuleGroup = Action("DescribeRuleGroup")
DisassociateSubnets = Action("DisassociateSubnets")
ListFirewallPolicies = Action("ListFirewallPolicies")
ListFirewalls = Action("ListFirewalls")
ListRuleGroups = Action("ListRuleGroups")
ListTagsForResource = Action("ListTagsForResource")
PutResourcePolicy = Action("PutResourcePolicy")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateFirewallDeleteProtection = Action("UpdateFirewallDeleteProtection")
UpdateFirewallDescription = Action("UpdateFirewallDescription")
UpdateFirewallPolicy = Action("UpdateFirewallPolicy")
UpdateFirewallPolicyChangeProtection = Action("UpdateFirewallPolicyChangeProtection")
UpdateLoggingConfiguration = Action("UpdateLoggingConfiguration")
UpdateRuleGroup = Action("UpdateRuleGroup")
UpdateSubnetChangeProtection = Action("UpdateSubnetChangeProtection")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon EC2 Auto Scaling"
prefix = "autoscaling"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AttachInstances = Action("AttachInstances")
AttachLoadBalancerTargetGroups = Action("AttachLoadBalancerTargetGroups")
AttachLoadBalancers = Action("AttachLoadBalancers")
BatchDeleteScheduledAction = Action("BatchDeleteScheduledAction")
BatchPutScheduledUpdateGroupAction = Action("BatchPutScheduledUpdateGroupAction")
CancelInstanceRefresh = Action("CancelInstanceRefresh")
CompleteLifecycleAction = Action("CompleteLifecycleAction")
CreateAutoScalingGroup = Action("CreateAutoScalingGroup")
CreateLaunchConfiguration = Action("CreateLaunchConfiguration")
CreateOrUpdateTags = Action("CreateOrUpdateTags")
DeleteAutoScalingGroup = Action("DeleteAutoScalingGroup")
DeleteLaunchConfiguration = Action("DeleteLaunchConfiguration")
DeleteLifecycleHook = Action("DeleteLifecycleHook")
DeleteNotificationConfiguration = Action("DeleteNotificationConfiguration")
DeletePolicy = Action("DeletePolicy")
DeleteScheduledAction = Action("DeleteScheduledAction")
DeleteTags = Action("DeleteTags")
DeleteWarmPool = Action("DeleteWarmPool")
DescribeAccountLimits = Action("DescribeAccountLimits")
DescribeAdjustmentTypes = Action("DescribeAdjustmentTypes")
DescribeAutoScalingGroups = Action("DescribeAutoScalingGroups")
DescribeAutoScalingInstances = Action("DescribeAutoScalingInstances")
DescribeAutoScalingNotificationTypes = Action("DescribeAutoScalingNotificationTypes")
DescribeInstanceRefreshes = Action("DescribeInstanceRefreshes")
DescribeLaunchConfigurations = Action("DescribeLaunchConfigurations")
DescribeLifecycleHookTypes = Action("DescribeLifecycleHookTypes")
DescribeLifecycleHooks = Action("DescribeLifecycleHooks")
DescribeLoadBalancerTargetGroups = Action("DescribeLoadBalancerTargetGroups")
DescribeLoadBalancers = Action("DescribeLoadBalancers")
DescribeMetricCollectionTypes = Action("DescribeMetricCollectionTypes")
DescribeNotificationConfigurations = Action("DescribeNotificationConfigurations")
DescribePolicies = Action("DescribePolicies")
DescribeScalingActivities = Action("DescribeScalingActivities")
DescribeScalingProcessTypes = Action("DescribeScalingProcessTypes")
DescribeScheduledActions = Action("DescribeScheduledActions")
DescribeTags = Action("DescribeTags")
DescribeTerminationPolicyTypes = Action("DescribeTerminationPolicyTypes")
DescribeWarmPool = Action("DescribeWarmPool")
DetachInstances = Action("DetachInstances")
DetachLoadBalancerTargetGroups = Action("DetachLoadBalancerTargetGroups")
DetachLoadBalancers = Action("DetachLoadBalancers")
DisableMetricsCollection = Action("DisableMetricsCollection")
EnableMetricsCollection = Action("EnableMetricsCollection")
EnterStandby = Action("EnterStandby")
ExecutePolicy = Action("ExecutePolicy")
ExitStandby = Action("ExitStandby")
GetPredictiveScalingForecast = Action("GetPredictiveScalingForecast")
PutLifecycleHook = Action("PutLifecycleHook")
PutNotificationConfiguration = Action("PutNotificationConfiguration")
PutScalingPolicy = Action("PutScalingPolicy")
PutScheduledUpdateGroupAction = Action("PutScheduledUpdateGroupAction")
PutWarmPool = Action("PutWarmPool")
RecordLifecycleActionHeartbeat = Action("RecordLifecycleActionHeartbeat")
ResumeProcesses = Action("ResumeProcesses")
SetDesiredCapacity = Action("SetDesiredCapacity")
SetInstanceHealth = Action("SetInstanceHealth")
SetInstanceProtection = Action("SetInstanceProtection")
StartInstanceRefresh = Action("StartInstanceRefresh")
SuspendProcesses = Action("SuspendProcesses")
TerminateInstanceInAutoScalingGroup = Action("TerminateInstanceInAutoScalingGroup")
UpdateAutoScalingGroup = Action("UpdateAutoScalingGroup")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Lake Formation"
prefix = "lakeformation"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchGrantPermissions = Action("BatchGrantPermissions")
BatchRevokePermissions = Action("BatchRevokePermissions")
DeregisterResource = Action("DeregisterResource")
DescribeResource = Action("DescribeResource")
GetDataAccess = Action("GetDataAccess")
GetDataLakeSettings = Action("GetDataLakeSettings")
GetEffectivePermissionsForPath = Action("GetEffectivePermissionsForPath")
GrantPermissions = Action("GrantPermissions")
ListPermissions = Action("ListPermissions")
ListResources = Action("ListResources")
PutDataLakeSettings = Action("PutDataLakeSettings")
RegisterResource = Action("RegisterResource")
RevokePermissions = Action("RevokePermissions")
UpdateResource = Action("UpdateResource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon S3"
prefix = "s3"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        # account is empty for S3 buckets
        if not resource.startswith(("accesspoint/", "job/", "storage-lens/")):
            account = ""
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AbortMultipartUpload = Action("AbortMultipartUpload")
BypassGovernanceRetention = Action("BypassGovernanceRetention")
CreateAccessPoint = Action("CreateAccessPoint")
CreateAccessPointForObjectLambda = Action("CreateAccessPointForObjectLambda")
CreateBucket = Action("CreateBucket")
CreateJob = Action("CreateJob")
CreateMultiRegionAccessPoint = Action("CreateMultiRegionAccessPoint")
DeleteAccessPoint = Action("DeleteAccessPoint")
DeleteAccessPointForObjectLambda = Action("DeleteAccessPointForObjectLambda")
DeleteAccessPointPolicy = Action("DeleteAccessPointPolicy")
DeleteAccessPointPolicyForObjectLambda = Action(
    "DeleteAccessPointPolicyForObjectLambda"
)
DeleteBucket = Action("DeleteBucket")
DeleteBucketOwnershipControls = Action("DeleteBucketOwnershipControls")
DeleteBucketPolicy = Action("DeleteBucketPolicy")
DeleteBucketWebsite = Action("DeleteBucketWebsite")
DeleteJobTagging = Action("DeleteJobTagging")
DeleteMultiRegionAccessPoint = Action("DeleteMultiRegionAccessPoint")
DeleteObject = Action("DeleteObject")
DeleteObjectTagging = Action("DeleteObjectTagging")
DeleteObjectVersion = Action("DeleteObjectVersion")
DeleteObjectVersionTagging = Action("DeleteObjectVersionTagging")
DeleteStorageLensConfiguration = Action("DeleteStorageLensConfiguration")
DeleteStorageLensConfigurationTagging = Action("DeleteStorageLensConfigurationTagging")
DescribeJob = Action("DescribeJob")
DescribeMultiRegionAccessPointOperation = Action(
    "DescribeMultiRegionAccessPointOperation"
)
GetAccelerateConfiguration = Action("GetAccelerateConfiguration")
GetAccessPoint = Action("GetAccessPoint")
GetAccessPointConfigurationForObjectLambda = Action(
    "GetAccessPointConfigurationForObjectLambda"
)
GetAccessPointForObjectLambda = Action("GetAccessPointForObjectLambda")
GetAccessPointPolicy = Action("GetAccessPointPolicy")
GetAccessPointPolicyForObjectLambda = Action("GetAccessPointPolicyForObjectLambda")
GetAccessPointPolicyStatus = Action("GetAccessPointPolicyStatus")
GetAccessPointPolicyStatusForObjectLambda = Action(
    "GetAccessPointPolicyStatusForObjectLambda"
)
GetAccountPublicAccessBlock = Action("GetAccountPublicAccessBlock")
GetAnalyticsConfiguration = Action("GetAnalyticsConfiguration")
GetBucketAcl = Action("GetBucketAcl")
GetBucketCORS = Action("GetBucketCORS")
GetBucketLocation = Action("GetBucketLocation")
GetBucketLogging = Action("GetBucketLogging")
GetBucketNotification = Action("GetBucketNotification")
GetBucketObjectLockConfiguration = Action("GetBucketObjectLockConfiguration")
GetBucketOwnershipControls = Action("GetBucketOwnershipControls")
GetBucketPolicy = Action("GetBucketPolicy")
GetBucketPolicyStatus = Action("GetBucketPolicyStatus")
GetBucketPublicAccessBlock = Action("GetBucketPublicAccessBlock")
GetBucketRequestPayment = Action("GetBucketRequestPayment")
GetBucketTagging = Action("GetBucketTagging")
GetBucketVersioning = Action("GetBucketVersioning")
GetBucketWebsite = Action("GetBucketWebsite")
GetEncryptionConfiguration = Action("GetEncryptionConfiguration")
GetIntelligentTieringConfiguration = Action("GetIntelligentTieringConfiguration")
GetInventoryConfiguration = Action("GetInventoryConfiguration")
GetIpConfiguration = Action("GetIpConfiguration")
GetJobTagging = Action("GetJobTagging")
GetLifecycleConfiguration = Action("GetLifecycleConfiguration")
GetMetricsConfiguration = Action("GetMetricsConfiguration")
GetMultiRegionAccessPoint = Action("GetMultiRegionAccessPoint")
GetMultiRegionAccessPointPolicy = Action("GetMultiRegionAccessPointPolicy")
GetMultiRegionAccessPointPolicyStatus = Action("GetMultiRegionAccessPointPolicyStatus")
GetObject = Action("GetObject")
GetObjectAcl = Action("GetObjectAcl")
GetObjectLegalHold = Action("GetObjectLegalHold")
GetObjectRetention = Action("GetObjectRetention")
GetObjectTagging = Action("GetObjectTagging")
GetObjectTorrent = Action("GetObjectTorrent")
GetObjectVersion = Action("GetObjectVersion")
GetObjectVersionAcl = Action("GetObjectVersionAcl")
GetObjectVersionForReplication = Action("GetObjectVersionForReplication")
GetObjectVersionTagging = Action("GetObjectVersionTagging")
GetObjectVersionTorrent = Action("GetObjectVersionTorrent")
GetReplicationConfiguration = Action("GetReplicationConfiguration")
GetStorageLensConfiguration = Action("GetStorageLensConfiguration")
GetStorageLensConfigurationTagging = Action("GetStorageLensConfigurationTagging")
GetStorageLensDashboard = Action("GetStorageLensDashboard")
HeadBucket = Action("HeadBucket")
ListAccessPoints = Action("ListAccessPoints")
ListAccessPointsForObjectLambda = Action("ListAccessPointsForObjectLambda")
ListAllMyBuckets = Action("ListAllMyBuckets")
ListBucket = Action("ListBucket")
ListBucketByTags = Action("ListBucketByTags")
ListBucketMultipartUploads = Action("ListBucketMultipartUploads")
ListBucketVersions = Action("ListBucketVersions")
ListJobs = Action("ListJobs")
ListMultiRegionAccessPoints = Action("ListMultiRegionAccessPoints")
ListMultipartUploadParts = Action("ListMultipartUploadParts")
ListObjects = Action("ListObjects")
ListStorageLensConfigurations = Action("ListStorageLensConfigurations")
ObjectOwnerOverrideToBucketOwner = Action("ObjectOwnerOverrideToBucketOwner")
PutAccelerateConfiguration = Action("PutAccelerateConfiguration")
PutAccessPointConfigurationForObjectLambda = Action(
    "PutAccessPointConfigurationForObjectLambda"
)
PutAccessPointPolicy = Action("PutAccessPointPolicy")
PutAccessPointPolicyForObjectLambda = Action("PutAccessPointPolicyForObjectLambda")
PutAccountPublicAccessBlock = Action("PutAccountPublicAccessBlock")
PutAnalyticsConfiguration = Action("PutAnalyticsConfiguration")
PutBucketAcl = Action("PutBucketAcl")
PutBucketCORS = Action("PutBucketCORS")
PutBucketLogging = Action("PutBucketLogging")
PutBucketNotification = Action("PutBucketNotification")
PutBucketObjectLockConfiguration = Action("PutBucketObjectLockConfiguration")
PutBucketOwnershipControls = Action("PutBucketOwnershipControls")
PutBucketPolicy = Action("PutBucketPolicy")
PutBucketPublicAccessBlock = Action("PutBucketPublicAccessBlock")
PutBucketRequestPayment = Action("PutBucketRequestPayment")
PutBucketTagging = Action("PutBucketTagging")
PutBucketVersioning = Action("PutBucketVersioning")
PutBucketWebsite = Action("PutBucketWebsite")
PutEncryptionConfiguration = Action("PutEncryptionConfiguration")
PutIntelligentTieringConfiguration = Action("PutIntelligentTieringConfiguration")
PutInventoryConfiguration = Action("PutInventoryConfiguration")
PutIpConfiguration = Action("PutIpConfiguration")
PutJobTagging = Action("PutJobTagging")
PutLifecycleConfiguration = Action("PutLifecycleConfiguration")
PutMetricsConfiguration = Action("PutMetricsConfiguration")
PutMultiRegionAccessPointPolicy = Action("PutMultiRegionAccessPointPolicy")
PutObject = Action("PutObject")
PutObjectAcl = Action("PutObjectAcl")
PutObjectLegalHold = Action("PutObjectLegalHold")
PutObjectRetention = Action("PutObjectRetention")
PutObjectTagging = Action("PutObjectTagging")
PutObjectVersionAcl = Action("PutObjectVersionAcl")
PutObjectVersionTagging = Action("PutObjectVersionTagging")
PutReplicationConfiguration = Action("PutReplicationConfiguration")
PutStorageLensConfiguration = Action("PutStorageLensConfiguration")
PutStorageLensConfigurationTagging = Action("PutStorageLensConfigurationTagging")
ReplicateDelete = Action("ReplicateDelete")
ReplicateObject = Action("ReplicateObject")
ReplicateTags = Action("ReplicateTags")
RestoreObject = Action("RestoreObject")
UpdateJobPriority = Action("UpdateJobPriority")
UpdateJobStatus = Action("UpdateJobStatus")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon EMR on EKS (EMR Containers)"
prefix = "emr-containers"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelJobRun = Action("CancelJobRun")
CreateManagedEndpoint = Action("CreateManagedEndpoint")
CreateVirtualCluster = Action("CreateVirtualCluster")
DeleteManagedEndpoint = Action("DeleteManagedEndpoint")
DeleteVirtualCluster = Action("DeleteVirtualCluster")
DescribeJobRun = Action("DescribeJobRun")
DescribeManagedEndpoint = Action("DescribeManagedEndpoint")
DescribeVirtualCluster = Action("DescribeVirtualCluster")
ListJobRuns = Action("ListJobRuns")
ListManagedEndpoints = Action("ListManagedEndpoints")
ListTagsForResource = Action("ListTagsForResource")
ListVirtualClusters = Action("ListVirtualClusters")
StartJobRun = Action("StartJobRun")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")



import json
import unittest

import awacs.aws as aws
import awacs.s3 as s3


class TestConditions(unittest.TestCase):
    def test_for_all_values(self):
        c = aws.Condition(
            aws.ForAllValuesStringLike(
                "dynamodb:requestedAttributes", ["PostDateTime", "Message", "Tags"]
            )
        )
        pd = aws.PolicyDocument(
            Statement=[
                aws.Statement(
                    Action=[s3.ListBucket],
                    Effect=aws.Allow,
                    Resource=[s3.ARN("myBucket")],
                    Condition=c,
                )
            ]
        )
        self.assertEqual(
            {
                "Statement": [
                    {
                        "Action": ["s3:ListBucket"],
                        "Condition": {
                            "ForAllValues:StringLike": {
                                "dynamodb:requestedAttributes": [
                                    "PostDateTime",
                                    "Message",
                                    "Tags",
                                ]
                            }
                        },
                        "Effect": "Allow",
                        "Resource": ["arn:aws:s3:::myBucket"],
                    }
                ]
            },
            json.loads(pd.to_json()),
        )



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Lightsail"
prefix = "lightsail"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AllocateStaticIp = Action("AllocateStaticIp")
AttachCertificateToDistribution = Action("AttachCertificateToDistribution")
AttachDisk = Action("AttachDisk")
AttachInstancesToLoadBalancer = Action("AttachInstancesToLoadBalancer")
AttachLoadBalancerTlsCertificate = Action("AttachLoadBalancerTlsCertificate")
AttachStaticIp = Action("AttachStaticIp")
CloseInstancePublicPorts = Action("CloseInstancePublicPorts")
CopySnapshot = Action("CopySnapshot")
CreateBucket = Action("CreateBucket")
CreateBucketAccessKey = Action("CreateBucketAccessKey")
CreateCertificate = Action("CreateCertificate")
CreateCloudFormationStack = Action("CreateCloudFormationStack")
CreateContactMethod = Action("CreateContactMethod")
CreateContainerService = Action("CreateContainerService")
CreateContainerServiceDeployment = Action("CreateContainerServiceDeployment")
CreateContainerServiceRegistryLogin = Action("CreateContainerServiceRegistryLogin")
CreateDisk = Action("CreateDisk")
CreateDiskFromSnapshot = Action("CreateDiskFromSnapshot")
CreateDiskSnapshot = Action("CreateDiskSnapshot")
CreateDistribution = Action("CreateDistribution")
CreateDomain = Action("CreateDomain")
CreateDomainEntry = Action("CreateDomainEntry")
CreateInstanceSnapshot = Action("CreateInstanceSnapshot")
CreateInstances = Action("CreateInstances")
CreateInstancesFromSnapshot = Action("CreateInstancesFromSnapshot")
CreateKeyPair = Action("CreateKeyPair")
CreateLoadBalancer = Action("CreateLoadBalancer")
CreateLoadBalancerTlsCertificate = Action("CreateLoadBalancerTlsCertificate")
CreateRelationalDatabase = Action("CreateRelationalDatabase")
CreateRelationalDatabaseFromSnapshot = Action("CreateRelationalDatabaseFromSnapshot")
CreateRelationalDatabaseSnapshot = Action("CreateRelationalDatabaseSnapshot")
DeleteAlarm = Action("DeleteAlarm")
DeleteAutoSnapshot = Action("DeleteAutoSnapshot")
DeleteBucket = Action("DeleteBucket")
DeleteBucketAccessKey = Action("DeleteBucketAccessKey")
DeleteCertificate = Action("DeleteCertificate")
DeleteContactMethod = Action("DeleteContactMethod")
DeleteContainerImage = Action("DeleteContainerImage")
DeleteContainerService = Action("DeleteContainerService")
DeleteDisk = Action("DeleteDisk")
DeleteDiskSnapshot = Action("DeleteDiskSnapshot")
DeleteDistribution = Action("DeleteDistribution")
DeleteDomain = Action("DeleteDomain")
DeleteDomainEntry = Action("DeleteDomainEntry")
DeleteInstance = Action("DeleteInstance")
DeleteInstanceSnapshot = Action("DeleteInstanceSnapshot")
DeleteKeyPair = Action("DeleteKeyPair")
DeleteKnownHostKeys = Action("DeleteKnownHostKeys")
DeleteLoadBalancer = Action("DeleteLoadBalancer")
DeleteLoadBalancerTlsCertificate = Action("DeleteLoadBalancerTlsCertificate")
DeleteRelationalDatabase = Action("DeleteRelationalDatabase")
DeleteRelationalDatabaseSnapshot = Action("DeleteRelationalDatabaseSnapshot")
DetachCertificateFromDistribution = Action("DetachCertificateFromDistribution")
DetachDisk = Action("DetachDisk")
DetachInstancesFromLoadBalancer = Action("DetachInstancesFromLoadBalancer")
DetachStaticIp = Action("DetachStaticIp")
DisableAddOn = Action("DisableAddOn")
DownloadDefaultKeyPair = Action("DownloadDefaultKeyPair")
EnableAddOn = Action("EnableAddOn")
ExportSnapshot = Action("ExportSnapshot")
GetActiveNames = Action("GetActiveNames")
GetAlarms = Action("GetAlarms")
GetAutoSnapshots = Action("GetAutoSnapshots")
GetBlueprints = Action("GetBlueprints")
GetBucketAccessKeys = Action("GetBucketAccessKeys")
GetBucketBundles = Action("GetBucketBundles")
GetBucketMetricData = Action("GetBucketMetricData")
GetBuckets = Action("GetBuckets")
GetBundles = Action("GetBundles")
GetCertificates = Action("GetCertificates")
GetCloudFormationStackRecords = Action("GetCloudFormationStackRecords")
GetContactMethods = Action("GetContactMethods")
GetContainerAPIMetadata = Action("GetContainerAPIMetadata")
GetContainerImages = Action("GetContainerImages")
GetContainerLog = Action("GetContainerLog")
GetContainerServiceDeployments = Action("GetContainerServiceDeployments")
GetContainerServiceMetricData = Action("GetContainerServiceMetricData")
GetContainerServicePowers = Action("GetContainerServicePowers")
GetContainerServices = Action("GetContainerServices")
GetDisk = Action("GetDisk")
GetDiskSnapshot = Action("GetDiskSnapshot")
GetDiskSnapshots = Action("GetDiskSnapshots")
GetDisks = Action("GetDisks")
GetDistributionBundles = Action("GetDistributionBundles")
GetDistributionLatestCacheReset = Action("GetDistributionLatestCacheReset")
GetDistributionMetricData = Action("GetDistributionMetricData")
GetDistributions = Action("GetDistributions")
GetDomain = Action("GetDomain")
GetDomains = Action("GetDomains")
GetExportSnapshotRecords = Action("GetExportSnapshotRecords")
GetInstance = Action("GetInstance")
GetInstanceAccessDetails = Action("GetInstanceAccessDetails")
GetInstanceMetricData = Action("GetInstanceMetricData")
GetInstancePortStates = Action("GetInstancePortStates")
GetInstanceSnapshot = Action("GetInstanceSnapshot")
GetInstanceSnapshots = Action("GetInstanceSnapshots")
GetInstanceState = Action("GetInstanceState")
GetInstances = Action("GetInstances")
GetKeyPair = Action("GetKeyPair")
GetKeyPairs = Action("GetKeyPairs")
GetLoadBalancer = Action("GetLoadBalancer")
GetLoadBalancerMetricData = Action("GetLoadBalancerMetricData")
GetLoadBalancerTlsCertificates = Action("GetLoadBalancerTlsCertificates")
GetLoadBalancers = Action("GetLoadBalancers")
GetOperation = Action("GetOperation")
GetOperations = Action("GetOperations")
GetOperationsForResource = Action("GetOperationsForResource")
GetRegions = Action("GetRegions")
GetRelationalDatabase = Action("GetRelationalDatabase")
GetRelationalDatabaseBlueprints = Action("GetRelationalDatabaseBlueprints")
GetRelationalDatabaseBundles = Action("GetRelationalDatabaseBundles")
GetRelationalDatabaseEvents = Action("GetRelationalDatabaseEvents")
GetRelationalDatabaseLogEvents = Action("GetRelationalDatabaseLogEvents")
GetRelationalDatabaseLogStreams = Action("GetRelationalDatabaseLogStreams")
GetRelationalDatabaseMasterUserPassword = Action(
    "GetRelationalDatabaseMasterUserPassword"
)
GetRelationalDatabaseMetricData = Action("GetRelationalDatabaseMetricData")
GetRelationalDatabaseParameters = Action("GetRelationalDatabaseParameters")
GetRelationalDatabaseSnapshot = Action("GetRelationalDatabaseSnapshot")
GetRelationalDatabaseSnapshots = Action("GetRelationalDatabaseSnapshots")
GetRelationalDatabases = Action("GetRelationalDatabases")
GetStaticIp = Action("GetStaticIp")
GetStaticIps = Action("GetStaticIps")
ImportKeyPair = Action("ImportKeyPair")
IsVpcPeered = Action("IsVpcPeered")
OpenInstancePublicPorts = Action("OpenInstancePublicPorts")
PeerVpc = Action("PeerVpc")
PutAlarm = Action("PutAlarm")
PutInstancePublicPorts = Action("PutInstancePublicPorts")
RebootInstance = Action("RebootInstance")
RebootRelationalDatabase = Action("RebootRelationalDatabase")
RegisterContainerImage = Action("RegisterContainerImage")
ReleaseStaticIp = Action("ReleaseStaticIp")
ResetDistributionCache = Action("ResetDistributionCache")
SendContactMethodVerification = Action("SendContactMethodVerification")
SetIpAddressType = Action("SetIpAddressType")
SetResourceAccessForBucket = Action("SetResourceAccessForBucket")
StartInstance = Action("StartInstance")
StartRelationalDatabase = Action("StartRelationalDatabase")
StopInstance = Action("StopInstance")
StopRelationalDatabase = Action("StopRelationalDatabase")
TagResource = Action("TagResource")
TestAlarm = Action("TestAlarm")
UnpeerVpc = Action("UnpeerVpc")
UntagResource = Action("UntagResource")
UpdateBucket = Action("UpdateBucket")
UpdateBucketBundle = Action("UpdateBucketBundle")
UpdateContainerService = Action("UpdateContainerService")
UpdateDistribution = Action("UpdateDistribution")
UpdateDistributionBundle = Action("UpdateDistributionBundle")
UpdateDomainEntry = Action("UpdateDomainEntry")
UpdateLoadBalancerAttribute = Action("UpdateLoadBalancerAttribute")
UpdateRelationalDatabase = Action("UpdateRelationalDatabase")
UpdateRelationalDatabaseParameters = Action("UpdateRelationalDatabaseParameters")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from abc import ABCMeta, abstractmethod
from typing import Any, Dict, List, Optional, Union

from . import AWSHelperFn, AWSProperty

try:
    from typing import Literal  # type: ignore[attr-defined]
except ImportError:
    from typing_extensions import Literal

# Policy effect constants.
Allow = "Allow"
Deny = "Deny"

# Policy principal constants.
Everybody = "*"

# Policy condition key constants.
CurrentTime = "aws:CurrentTime"
EpochTime = "aws:EpochTime"
MultiFactorAuthAge = "aws:MultiFactorAuthAge"
MultiFactorAuthPresent = "aws:MultiFactorAuthPresent"
PrincipalArn = "aws:PrincipalArn"
PrincipalOrgID = "aws:PrincipalOrgID"
PrincipalType = "aws:PrincipalType"
Referer = "aws:Referer"
RequestedRegion = "aws:RequestedRegion"
SecureTransport = "aws:SecureTransport"
SourceAccount = "aws:SourceAccount"
SourceArn = "aws:SourceArn"
SourceIp = "aws:SourceIp"
SourceVpc = "aws:SourceVpc"
SourceVpce = "aws:SourceVpce"
TagKeys = "aws:TagKeys"
TokenIssueTime = "aws:TokenIssueTime"
UserAgent = "aws:UserAgent"
userid = "aws:userid"
username = "aws:username"
VpcSourceIp = "aws:VpcSourceIp"


class Action(AWSHelperFn):
    def __init__(self, prefix: str, action: str = None) -> None:
        self.prefix = prefix
        if prefix == "*" and action:
            raise ValueError("Action not supported with wildcard prefix")
        else:
            self.action = action

    def JSONrepr(self) -> str:
        if self.prefix == "*" or not self.action:
            return self.prefix
        else:
            return "".join([self.prefix, ":", self.action])


class BaseARN(AWSHelperFn):
    def __init__(
        self, service: str, resource: str, region: str = "", account: str = ""
    ) -> None:
        region_string = region.lower()
        if region == "${AWS::Region}":
            aws_partition = "${AWS::Partition}"
        elif region_string.startswith("cn-"):
            aws_partition = "aws-cn"
        elif region_string.startswith("us-gov"):
            aws_partition = "aws-us-gov"
        else:
            aws_partition = "aws"

        if service == "iam":
            region = ""
        elif service == "s3" and not resource.startswith(
            ("accesspoint/", "job/", "storage-lens/")
        ):
            region = ""

        self.data = "arn:%s:%s:%s:%s:%s" % (
            aws_partition,
            service,
            region,
            account,
            resource,
        )

    def JSONrepr(self) -> str:
        return self.data


class ConditionElement(AWSHelperFn, metaclass=ABCMeta):
    def __init__(self, data: Union[str, dict], value: Any = None) -> None:
        """Create a ConditionElement

        There are two supported ways to create a new ConditionElement.
        For a simple key/value pair use something of the form:
            StringEquals('s3:prefix', ['', 'home/']),
        If more than one condition is needed, pass a dict:
            StringEquals({
                's3:prefix': ['', 'home/'],
                's3:delimiter': ['/'],
            }),
        """
        self.cond_dict: Optional[dict] = None
        if value is not None:
            self.key = data
            self.value = value
        else:
            assert isinstance(data, dict)
            self.cond_dict = data

    def get_dict(self) -> dict:
        if self.cond_dict:
            return self.cond_dict
        else:
            return {self.key: self.value}

    @property
    @abstractmethod
    def condition(self) -> str:
        raise NotImplementedError


class Condition(AWSHelperFn):
    def __init__(
        self, conditions: Union[ConditionElement, List[ConditionElement]]
    ) -> None:
        if isinstance(conditions, ConditionElement):
            self.conditions = [conditions]
        elif isinstance(conditions, list):
            for c in conditions:
                if not isinstance(c, ConditionElement):
                    raise ValueError("ConditionElement is type %s" % (type(c),))
            self.conditions = conditions
        else:
            raise TypeError

    def JSONrepr(self) -> dict:
        d = {}
        for c in self.conditions:
            d[c.condition] = c.get_dict()
        return d


class Principal(AWSHelperFn):
    data: Union[Literal["*"], Dict[str, Any]]
    VALID_PRINCIPALS = ["AWS", "CanonicalUser", "Federated", "Service"]

    def __init__(self, principal: str, resources: Any = None) -> None:
        if principal == "*":
            if resources:
                raise ValueError("Cannot provide resources if principal is " "'*'.")
            self.data = "*"
        else:
            if not resources:
                raise ValueError("Must provide resources with principal.")
            if principal not in self.VALID_PRINCIPALS:
                raise ValueError(
                    "Principal must be one of: %s" % (", ".join(self.VALID_PRINCIPALS))
                )
            self.data = {principal: resources}

    def JSONrepr(self) -> Union[Literal["*"], Dict[str, Any]]:
        return self.data


class AWSPrincipal(Principal):
    def __init__(self, principals: Any) -> None:
        super().__init__("AWS", principals)


def effect(x: str) -> str:
    if x not in [Allow, Deny]:
        raise ValueError(x)
    return x


class Statement(AWSProperty):
    props = {
        "Action": ([Action], False),
        "Condition": (Condition, False),
        "Effect": (effect, True),
        "NotAction": (list, False),
        "NotPrincipal": (Principal, False),
        "Principal": (Principal, False),
        "Resource": (list, False),
        "NotResource": (list, False),
        "Sid": (str, False),
    }


class Policy(AWSProperty):
    props = {
        "Id": (str, False),
        "Statement": ([Statement], True),
        "Version": (str, False),
    }

    def JSONrepr(self) -> dict:
        return self.properties


class PolicyDocument(Policy):
    pass


# Generated Conditions


class ArnEquals(ConditionElement):
    condition = "ArnEquals"


class ArnEqualsIfExists(ConditionElement):
    condition = "ArnEqualsIfExists"


class ForAnyValueArnEquals(ConditionElement):
    condition = "ForAnyValue:ArnEquals"


class ForAnyValueArnEqualsIfExists(ConditionElement):
    condition = "ForAnyValue:ArnEqualsIfExists"


class ForAllValuesArnEquals(ConditionElement):
    condition = "ForAllValues:ArnEquals"


class ForAllValuesArnEqualsIfExists(ConditionElement):
    condition = "ForAllValues:ArnEqualsIfExists"


class ArnNotEquals(ConditionElement):
    condition = "ArnNotEquals"


class ArnNotEqualsIfExists(ConditionElement):
    condition = "ArnNotEqualsIfExists"


class ForAnyValueArnNotEquals(ConditionElement):
    condition = "ForAnyValue:ArnNotEquals"


class ForAnyValueArnNotEqualsIfExists(ConditionElement):
    condition = "ForAnyValue:ArnNotEqualsIfExists"


class ForAllValuesArnNotEquals(ConditionElement):
    condition = "ForAllValues:ArnNotEquals"


class ForAllValuesArnNotEqualsIfExists(ConditionElement):
    condition = "ForAllValues:ArnNotEqualsIfExists"


class ArnLike(ConditionElement):
    condition = "ArnLike"


class ArnLikeIfExists(ConditionElement):
    condition = "ArnLikeIfExists"


class ForAnyValueArnLike(ConditionElement):
    condition = "ForAnyValue:ArnLike"


class ForAnyValueArnLikeIfExists(ConditionElement):
    condition = "ForAnyValue:ArnLikeIfExists"


class ForAllValuesArnLike(ConditionElement):
    condition = "ForAllValues:ArnLike"


class ForAllValuesArnLikeIfExists(ConditionElement):
    condition = "ForAllValues:ArnLikeIfExists"


class ArnNotLike(ConditionElement):
    condition = "ArnNotLike"


class ArnNotLikeIfExists(ConditionElement):
    condition = "ArnNotLikeIfExists"


class ForAnyValueArnNotLike(ConditionElement):
    condition = "ForAnyValue:ArnNotLike"


class ForAnyValueArnNotLikeIfExists(ConditionElement):
    condition = "ForAnyValue:ArnNotLikeIfExists"


class ForAllValuesArnNotLike(ConditionElement):
    condition = "ForAllValues:ArnNotLike"


class ForAllValuesArnNotLikeIfExists(ConditionElement):
    condition = "ForAllValues:ArnNotLikeIfExists"


class Bool(ConditionElement):
    condition = "Bool"


class BoolIfExists(ConditionElement):
    condition = "BoolIfExists"


class ForAnyValueBool(ConditionElement):
    condition = "ForAnyValue:Bool"


class ForAnyValueBoolIfExists(ConditionElement):
    condition = "ForAnyValue:BoolIfExists"


class ForAllValuesBool(ConditionElement):
    condition = "ForAllValues:Bool"


class ForAllValuesBoolIfExists(ConditionElement):
    condition = "ForAllValues:BoolIfExists"


class DateEquals(ConditionElement):
    condition = "DateEquals"


class DateEqualsIfExists(ConditionElement):
    condition = "DateEqualsIfExists"


class ForAnyValueDateEquals(ConditionElement):
    condition = "ForAnyValue:DateEquals"


class ForAnyValueDateEqualsIfExists(ConditionElement):
    condition = "ForAnyValue:DateEqualsIfExists"


class ForAllValuesDateEquals(ConditionElement):
    condition = "ForAllValues:DateEquals"


class ForAllValuesDateEqualsIfExists(ConditionElement):
    condition = "ForAllValues:DateEqualsIfExists"


class DateNotEquals(ConditionElement):
    condition = "DateNotEquals"


class DateNotEqualsIfExists(ConditionElement):
    condition = "DateNotEqualsIfExists"


class ForAnyValueDateNotEquals(ConditionElement):
    condition = "ForAnyValue:DateNotEquals"


class ForAnyValueDateNotEqualsIfExists(ConditionElement):
    condition = "ForAnyValue:DateNotEqualsIfExists"


class ForAllValuesDateNotEquals(ConditionElement):
    condition = "ForAllValues:DateNotEquals"


class ForAllValuesDateNotEqualsIfExists(ConditionElement):
    condition = "ForAllValues:DateNotEqualsIfExists"


class DateLessThan(ConditionElement):
    condition = "DateLessThan"


class DateLessThanIfExists(ConditionElement):
    condition = "DateLessThanIfExists"


class ForAnyValueDateLessThan(ConditionElement):
    condition = "ForAnyValue:DateLessThan"


class ForAnyValueDateLessThanIfExists(ConditionElement):
    condition = "ForAnyValue:DateLessThanIfExists"


class ForAllValuesDateLessThan(ConditionElement):
    condition = "ForAllValues:DateLessThan"


class ForAllValuesDateLessThanIfExists(ConditionElement):
    condition = "ForAllValues:DateLessThanIfExists"


class DateLessThanEquals(ConditionElement):
    condition = "DateLessThanEquals"


class DateLessThanEqualsIfExists(ConditionElement):
    condition = "DateLessThanEqualsIfExists"


class ForAnyValueDateLessThanEquals(ConditionElement):
    condition = "ForAnyValue:DateLessThanEquals"


class ForAnyValueDateLessThanEqualsIfExists(ConditionElement):
    condition = "ForAnyValue:DateLessThanEqualsIfExists"


class ForAllValuesDateLessThanEquals(ConditionElement):
    condition = "ForAllValues:DateLessThanEquals"


class ForAllValuesDateLessThanEqualsIfExists(ConditionElement):
    condition = "ForAllValues:DateLessThanEqualsIfExists"


class DateGreaterThan(ConditionElement):
    condition = "DateGreaterThan"


class DateGreaterThanIfExists(ConditionElement):
    condition = "DateGreaterThanIfExists"


class ForAnyValueDateGreaterThan(ConditionElement):
    condition = "ForAnyValue:DateGreaterThan"


class ForAnyValueDateGreaterThanIfExists(ConditionElement):
    condition = "ForAnyValue:DateGreaterThanIfExists"


class ForAllValuesDateGreaterThan(ConditionElement):
    condition = "ForAllValues:DateGreaterThan"


class ForAllValuesDateGreaterThanIfExists(ConditionElement):
    condition = "ForAllValues:DateGreaterThanIfExists"


class DateGreaterThanEquals(ConditionElement):
    condition = "DateGreaterThanEquals"


class DateGreaterThanEqualsIfExists(ConditionElement):
    condition = "DateGreaterThanEqualsIfExists"


class ForAnyValueDateGreaterThanEquals(ConditionElement):
    condition = "ForAnyValue:DateGreaterThanEquals"


class ForAnyValueDateGreaterThanEqualsIfExists(ConditionElement):
    condition = "ForAnyValue:DateGreaterThanEqualsIfExists"


class ForAllValuesDateGreaterThanEquals(ConditionElement):
    condition = "ForAllValues:DateGreaterThanEquals"


class ForAllValuesDateGreaterThanEqualsIfExists(ConditionElement):
    condition = "ForAllValues:DateGreaterThanEqualsIfExists"


class IpAddress(ConditionElement):
    condition = "IpAddress"


class IpAddressIfExists(ConditionElement):
    condition = "IpAddressIfExists"


class ForAnyValueIpAddress(ConditionElement):
    condition = "ForAnyValue:IpAddress"


class ForAnyValueIpAddressIfExists(ConditionElement):
    condition = "ForAnyValue:IpAddressIfExists"


class ForAllValuesIpAddress(ConditionElement):
    condition = "ForAllValues:IpAddress"


class ForAllValuesIpAddressIfExists(ConditionElement):
    condition = "ForAllValues:IpAddressIfExists"


class NotIpAddress(ConditionElement):
    condition = "NotIpAddress"


class NotIpAddressIfExists(ConditionElement):
    condition = "NotIpAddressIfExists"


class ForAnyValueNotIpAddress(ConditionElement):
    condition = "ForAnyValue:NotIpAddress"


class ForAnyValueNotIpAddressIfExists(ConditionElement):
    condition = "ForAnyValue:NotIpAddressIfExists"


class ForAllValuesNotIpAddress(ConditionElement):
    condition = "ForAllValues:NotIpAddress"


class ForAllValuesNotIpAddressIfExists(ConditionElement):
    condition = "ForAllValues:NotIpAddressIfExists"


class Null(ConditionElement):
    condition = "Null"


class NullIfExists(ConditionElement):
    condition = "NullIfExists"


class ForAnyValueNull(ConditionElement):
    condition = "ForAnyValue:Null"


class ForAnyValueNullIfExists(ConditionElement):
    condition = "ForAnyValue:NullIfExists"


class ForAllValuesNull(ConditionElement):
    condition = "ForAllValues:Null"


class ForAllValuesNullIfExists(ConditionElement):
    condition = "ForAllValues:NullIfExists"


class NumericEquals(ConditionElement):
    condition = "NumericEquals"


class NumericEqualsIfExists(ConditionElement):
    condition = "NumericEqualsIfExists"


class ForAnyValueNumericEquals(ConditionElement):
    condition = "ForAnyValue:NumericEquals"


class ForAnyValueNumericEqualsIfExists(ConditionElement):
    condition = "ForAnyValue:NumericEqualsIfExists"


class ForAllValuesNumericEquals(ConditionElement):
    condition = "ForAllValues:NumericEquals"


class ForAllValuesNumericEqualsIfExists(ConditionElement):
    condition = "ForAllValues:NumericEqualsIfExists"


class NumericNotEquals(ConditionElement):
    condition = "NumericNotEquals"


class NumericNotEqualsIfExists(ConditionElement):
    condition = "NumericNotEqualsIfExists"


class ForAnyValueNumericNotEquals(ConditionElement):
    condition = "ForAnyValue:NumericNotEquals"


class ForAnyValueNumericNotEqualsIfExists(ConditionElement):
    condition = "ForAnyValue:NumericNotEqualsIfExists"


class ForAllValuesNumericNotEquals(ConditionElement):
    condition = "ForAllValues:NumericNotEquals"


class ForAllValuesNumericNotEqualsIfExists(ConditionElement):
    condition = "ForAllValues:NumericNotEqualsIfExists"


class NumericLessThan(ConditionElement):
    condition = "NumericLessThan"


class NumericLessThanIfExists(ConditionElement):
    condition = "NumericLessThanIfExists"


class ForAnyValueNumericLessThan(ConditionElement):
    condition = "ForAnyValue:NumericLessThan"


class ForAnyValueNumericLessThanIfExists(ConditionElement):
    condition = "ForAnyValue:NumericLessThanIfExists"


class ForAllValuesNumericLessThan(ConditionElement):
    condition = "ForAllValues:NumericLessThan"


class ForAllValuesNumericLessThanIfExists(ConditionElement):
    condition = "ForAllValues:NumericLessThanIfExists"


class NumericLessThanEquals(ConditionElement):
    condition = "NumericLessThanEquals"


class NumericLessThanEqualsIfExists(ConditionElement):
    condition = "NumericLessThanEqualsIfExists"


class ForAnyValueNumericLessThanEquals(ConditionElement):
    condition = "ForAnyValue:NumericLessThanEquals"


class ForAnyValueNumericLessThanEqualsIfExists(ConditionElement):
    condition = "ForAnyValue:NumericLessThanEqualsIfExists"


class ForAllValuesNumericLessThanEquals(ConditionElement):
    condition = "ForAllValues:NumericLessThanEquals"


class ForAllValuesNumericLessThanEqualsIfExists(ConditionElement):
    condition = "ForAllValues:NumericLessThanEqualsIfExists"


class NumericGreaterThan(ConditionElement):
    condition = "NumericGreaterThan"


class NumericGreaterThanIfExists(ConditionElement):
    condition = "NumericGreaterThanIfExists"


class ForAnyValueNumericGreaterThan(ConditionElement):
    condition = "ForAnyValue:NumericGreaterThan"


class ForAnyValueNumericGreaterThanIfExists(ConditionElement):
    condition = "ForAnyValue:NumericGreaterThanIfExists"


class ForAllValuesNumericGreaterThan(ConditionElement):
    condition = "ForAllValues:NumericGreaterThan"


class ForAllValuesNumericGreaterThanIfExists(ConditionElement):
    condition = "ForAllValues:NumericGreaterThanIfExists"


class NumericGreaterThanEquals(ConditionElement):
    condition = "NumericGreaterThanEquals"


class NumericGreaterThanEqualsIfExists(ConditionElement):
    condition = "NumericGreaterThanEqualsIfExists"


class ForAnyValueNumericGreaterThanEquals(ConditionElement):
    condition = "ForAnyValue:NumericGreaterThanEquals"


class ForAnyValueNumericGreaterThanEqualsIfExists(ConditionElement):
    condition = "ForAnyValue:NumericGreaterThanEqualsIfExists"


class ForAllValuesNumericGreaterThanEquals(ConditionElement):
    condition = "ForAllValues:NumericGreaterThanEquals"


class ForAllValuesNumericGreaterThanEqualsIfExists(ConditionElement):
    condition = "ForAllValues:NumericGreaterThanEqualsIfExists"


class StringEquals(ConditionElement):
    condition = "StringEquals"


class StringEqualsIfExists(ConditionElement):
    condition = "StringEqualsIfExists"


class ForAnyValueStringEquals(ConditionElement):
    condition = "ForAnyValue:StringEquals"


class ForAnyValueStringEqualsIfExists(ConditionElement):
    condition = "ForAnyValue:StringEqualsIfExists"


class ForAllValuesStringEquals(ConditionElement):
    condition = "ForAllValues:StringEquals"


class ForAllValuesStringEqualsIfExists(ConditionElement):
    condition = "ForAllValues:StringEqualsIfExists"


class StringNotEquals(ConditionElement):
    condition = "StringNotEquals"


class StringNotEqualsIfExists(ConditionElement):
    condition = "StringNotEqualsIfExists"


class ForAnyValueStringNotEquals(ConditionElement):
    condition = "ForAnyValue:StringNotEquals"


class ForAnyValueStringNotEqualsIfExists(ConditionElement):
    condition = "ForAnyValue:StringNotEqualsIfExists"


class ForAllValuesStringNotEquals(ConditionElement):
    condition = "ForAllValues:StringNotEquals"


class ForAllValuesStringNotEqualsIfExists(ConditionElement):
    condition = "ForAllValues:StringNotEqualsIfExists"


class StringEqualsIgnoreCase(ConditionElement):
    condition = "StringEqualsIgnoreCase"


class StringEqualsIgnoreCaseIfExists(ConditionElement):
    condition = "StringEqualsIgnoreCaseIfExists"


class ForAnyValueStringEqualsIgnoreCase(ConditionElement):
    condition = "ForAnyValue:StringEqualsIgnoreCase"


class ForAnyValueStringEqualsIgnoreCaseIfExists(ConditionElement):
    condition = "ForAnyValue:StringEqualsIgnoreCaseIfExists"


class ForAllValuesStringEqualsIgnoreCase(ConditionElement):
    condition = "ForAllValues:StringEqualsIgnoreCase"


class ForAllValuesStringEqualsIgnoreCaseIfExists(ConditionElement):
    condition = "ForAllValues:StringEqualsIgnoreCaseIfExists"


class StringNotEqualsIgnoreCase(ConditionElement):
    condition = "StringNotEqualsIgnoreCase"


class StringNotEqualsIgnoreCaseIfExists(ConditionElement):
    condition = "StringNotEqualsIgnoreCaseIfExists"


class ForAnyValueStringNotEqualsIgnoreCase(ConditionElement):
    condition = "ForAnyValue:StringNotEqualsIgnoreCase"


class ForAnyValueStringNotEqualsIgnoreCaseIfExists(ConditionElement):
    condition = "ForAnyValue:StringNotEqualsIgnoreCaseIfExists"


class ForAllValuesStringNotEqualsIgnoreCase(ConditionElement):
    condition = "ForAllValues:StringNotEqualsIgnoreCase"


class ForAllValuesStringNotEqualsIgnoreCaseIfExists(ConditionElement):
    condition = "ForAllValues:StringNotEqualsIgnoreCaseIfExists"


class StringLike(ConditionElement):
    condition = "StringLike"


class StringLikeIfExists(ConditionElement):
    condition = "StringLikeIfExists"


class ForAnyValueStringLike(ConditionElement):
    condition = "ForAnyValue:StringLike"


class ForAnyValueStringLikeIfExists(ConditionElement):
    condition = "ForAnyValue:StringLikeIfExists"


class ForAllValuesStringLike(ConditionElement):
    condition = "ForAllValues:StringLike"


class ForAllValuesStringLikeIfExists(ConditionElement):
    condition = "ForAllValues:StringLikeIfExists"


class StringNotLike(ConditionElement):
    condition = "StringNotLike"


class StringNotLikeIfExists(ConditionElement):
    condition = "StringNotLikeIfExists"


class ForAnyValueStringNotLike(ConditionElement):
    condition = "ForAnyValue:StringNotLike"


class ForAnyValueStringNotLikeIfExists(ConditionElement):
    condition = "ForAnyValue:StringNotLikeIfExists"


class ForAllValuesStringNotLike(ConditionElement):
    condition = "ForAllValues:StringNotLike"


class ForAllValuesStringNotLikeIfExists(ConditionElement):
    condition = "ForAllValues:StringNotLikeIfExists"



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Identity And Access Management"
prefix = "iam"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddClientIDToOpenIDConnectProvider = Action("AddClientIDToOpenIDConnectProvider")
AddRoleToInstanceProfile = Action("AddRoleToInstanceProfile")
AddUserToGroup = Action("AddUserToGroup")
AttachGroupPolicy = Action("AttachGroupPolicy")
AttachRolePolicy = Action("AttachRolePolicy")
AttachUserPolicy = Action("AttachUserPolicy")
ChangePassword = Action("ChangePassword")
CreateAccessKey = Action("CreateAccessKey")
CreateAccountAlias = Action("CreateAccountAlias")
CreateGroup = Action("CreateGroup")
CreateInstanceProfile = Action("CreateInstanceProfile")
CreateLoginProfile = Action("CreateLoginProfile")
CreateOpenIDConnectProvider = Action("CreateOpenIDConnectProvider")
CreatePolicy = Action("CreatePolicy")
CreatePolicyVersion = Action("CreatePolicyVersion")
CreateRole = Action("CreateRole")
CreateSAMLProvider = Action("CreateSAMLProvider")
CreateServiceLinkedRole = Action("CreateServiceLinkedRole")
CreateServiceSpecificCredential = Action("CreateServiceSpecificCredential")
CreateUser = Action("CreateUser")
CreateVirtualMFADevice = Action("CreateVirtualMFADevice")
DeactivateMFADevice = Action("DeactivateMFADevice")
DeleteAccessKey = Action("DeleteAccessKey")
DeleteAccountAlias = Action("DeleteAccountAlias")
DeleteAccountPasswordPolicy = Action("DeleteAccountPasswordPolicy")
DeleteGroup = Action("DeleteGroup")
DeleteGroupPolicy = Action("DeleteGroupPolicy")
DeleteInstanceProfile = Action("DeleteInstanceProfile")
DeleteLoginProfile = Action("DeleteLoginProfile")
DeleteOpenIDConnectProvider = Action("DeleteOpenIDConnectProvider")
DeletePolicy = Action("DeletePolicy")
DeletePolicyVersion = Action("DeletePolicyVersion")
DeleteRole = Action("DeleteRole")
DeleteRolePermissionsBoundary = Action("DeleteRolePermissionsBoundary")
DeleteRolePolicy = Action("DeleteRolePolicy")
DeleteSAMLProvider = Action("DeleteSAMLProvider")
DeleteSSHPublicKey = Action("DeleteSSHPublicKey")
DeleteServerCertificate = Action("DeleteServerCertificate")
DeleteServiceLinkedRole = Action("DeleteServiceLinkedRole")
DeleteServiceSpecificCredential = Action("DeleteServiceSpecificCredential")
DeleteSigningCertificate = Action("DeleteSigningCertificate")
DeleteUser = Action("DeleteUser")
DeleteUserPermissionsBoundary = Action("DeleteUserPermissionsBoundary")
DeleteUserPolicy = Action("DeleteUserPolicy")
DeleteVirtualMFADevice = Action("DeleteVirtualMFADevice")
DetachGroupPolicy = Action("DetachGroupPolicy")
DetachRolePolicy = Action("DetachRolePolicy")
DetachUserPolicy = Action("DetachUserPolicy")
EnableMFADevice = Action("EnableMFADevice")
FinalizeSmsMfaRegistration = Action("FinalizeSmsMfaRegistration")
GenerateCredentialReport = Action("GenerateCredentialReport")
GenerateOrganizationsAccessReport = Action("GenerateOrganizationsAccessReport")
GenerateServiceLastAccessedDetails = Action("GenerateServiceLastAccessedDetails")
GetAccessKeyLastUsed = Action("GetAccessKeyLastUsed")
GetAccountAuthorizationDetails = Action("GetAccountAuthorizationDetails")
GetAccountPasswordPolicy = Action("GetAccountPasswordPolicy")
GetAccountSummary = Action("GetAccountSummary")
GetContextKeysForCustomPolicy = Action("GetContextKeysForCustomPolicy")
GetContextKeysForPrincipalPolicy = Action("GetContextKeysForPrincipalPolicy")
GetCredentialReport = Action("GetCredentialReport")
GetGroup = Action("GetGroup")
GetGroupPolicy = Action("GetGroupPolicy")
GetInstanceProfile = Action("GetInstanceProfile")
GetLoginProfile = Action("GetLoginProfile")
GetOpenIDConnectProvider = Action("GetOpenIDConnectProvider")
GetOrganizationsAccessReport = Action("GetOrganizationsAccessReport")
GetPolicy = Action("GetPolicy")
GetPolicyVersion = Action("GetPolicyVersion")
GetRole = Action("GetRole")
GetRolePolicy = Action("GetRolePolicy")
GetSAMLProvider = Action("GetSAMLProvider")
GetSSHPublicKey = Action("GetSSHPublicKey")
GetServerCertificate = Action("GetServerCertificate")
GetServiceLastAccessedDetails = Action("GetServiceLastAccessedDetails")
GetServiceLastAccessedDetailsWithEntities = Action(
    "GetServiceLastAccessedDetailsWithEntities"
)
GetServiceLinkedRoleDeletionStatus = Action("GetServiceLinkedRoleDeletionStatus")
GetUser = Action("GetUser")
GetUserPolicy = Action("GetUserPolicy")
ListAccessKeys = Action("ListAccessKeys")
ListAccountAliases = Action("ListAccountAliases")
ListAttachedGroupPolicies = Action("ListAttachedGroupPolicies")
ListAttachedRolePolicies = Action("ListAttachedRolePolicies")
ListAttachedUserPolicies = Action("ListAttachedUserPolicies")
ListEntitiesForPolicy = Action("ListEntitiesForPolicy")
ListGroupPolicies = Action("ListGroupPolicies")
ListGroups = Action("ListGroups")
ListGroupsForUser = Action("ListGroupsForUser")
ListInstanceProfileTags = Action("ListInstanceProfileTags")
ListInstanceProfiles = Action("ListInstanceProfiles")
ListInstanceProfilesForRole = Action("ListInstanceProfilesForRole")
ListMFADeviceTags = Action("ListMFADeviceTags")
ListMFADevices = Action("ListMFADevices")
ListOpenIDConnectProviderTags = Action("ListOpenIDConnectProviderTags")
ListOpenIDConnectProviders = Action("ListOpenIDConnectProviders")
ListPolicies = Action("ListPolicies")
ListPoliciesGrantingServiceAccess = Action("ListPoliciesGrantingServiceAccess")
ListPolicyTags = Action("ListPolicyTags")
ListPolicyVersions = Action("ListPolicyVersions")
ListRolePolicies = Action("ListRolePolicies")
ListRoleTags = Action("ListRoleTags")
ListRoles = Action("ListRoles")
ListSAMLProviderTags = Action("ListSAMLProviderTags")
ListSAMLProviders = Action("ListSAMLProviders")
ListSSHPublicKeys = Action("ListSSHPublicKeys")
ListServerCertificateTags = Action("ListServerCertificateTags")
ListServerCertificates = Action("ListServerCertificates")
ListServiceSpecificCredentials = Action("ListServiceSpecificCredentials")
ListSigningCertificates = Action("ListSigningCertificates")
ListUserPolicies = Action("ListUserPolicies")
ListUserTags = Action("ListUserTags")
ListUsers = Action("ListUsers")
ListVirtualMFADevices = Action("ListVirtualMFADevices")
PassRole = Action("PassRole")
PutGroupPolicy = Action("PutGroupPolicy")
PutRolePermissionsBoundary = Action("PutRolePermissionsBoundary")
PutRolePolicy = Action("PutRolePolicy")
PutUserPermissionsBoundary = Action("PutUserPermissionsBoundary")
PutUserPolicy = Action("PutUserPolicy")
RemoveClientIDFromOpenIDConnectProvider = Action(
    "RemoveClientIDFromOpenIDConnectProvider"
)
RemoveRoleFromInstanceProfile = Action("RemoveRoleFromInstanceProfile")
RemoveUserFromGroup = Action("RemoveUserFromGroup")
RequestSmsMfaRegistration = Action("RequestSmsMfaRegistration")
ResetServiceSpecificCredential = Action("ResetServiceSpecificCredential")
ResyncMFADevice = Action("ResyncMFADevice")
SetDefaultPolicyVersion = Action("SetDefaultPolicyVersion")
SetSecurityTokenServicePreferences = Action("SetSecurityTokenServicePreferences")
SimulateCustomPolicy = Action("SimulateCustomPolicy")
SimulatePrincipalPolicy = Action("SimulatePrincipalPolicy")
TagInstanceProfile = Action("TagInstanceProfile")
TagMFADevice = Action("TagMFADevice")
TagOpenIDConnectProvider = Action("TagOpenIDConnectProvider")
TagPolicy = Action("TagPolicy")
TagRole = Action("TagRole")
TagSAMLProvider = Action("TagSAMLProvider")
TagServerCertificate = Action("TagServerCertificate")
TagUser = Action("TagUser")
UntagInstanceProfile = Action("UntagInstanceProfile")
UntagMFADevice = Action("UntagMFADevice")
UntagOpenIDConnectProvider = Action("UntagOpenIDConnectProvider")
UntagPolicy = Action("UntagPolicy")
UntagRole = Action("UntagRole")
UntagSAMLProvider = Action("UntagSAMLProvider")
UntagServerCertificate = Action("UntagServerCertificate")
UntagUser = Action("UntagUser")
UpdateAccessKey = Action("UpdateAccessKey")
UpdateAccountPasswordPolicy = Action("UpdateAccountPasswordPolicy")
UpdateAssumeRolePolicy = Action("UpdateAssumeRolePolicy")
UpdateGroup = Action("UpdateGroup")
UpdateLoginProfile = Action("UpdateLoginProfile")
UpdateOpenIDConnectProviderThumbprint = Action("UpdateOpenIDConnectProviderThumbprint")
UpdateRole = Action("UpdateRole")
UpdateRoleDescription = Action("UpdateRoleDescription")
UpdateSAMLProvider = Action("UpdateSAMLProvider")
UpdateSSHPublicKey = Action("UpdateSSHPublicKey")
UpdateServerCertificate = Action("UpdateServerCertificate")
UpdateServiceSpecificCredential = Action("UpdateServiceSpecificCredential")
UpdateSigningCertificate = Action("UpdateSigningCertificate")
UpdateUser = Action("UpdateUser")
UploadSSHPublicKey = Action("UploadSSHPublicKey")
UploadServerCertificate = Action("UploadServerCertificate")
UploadSigningCertificate = Action("UploadSigningCertificate")
